@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmean.c,v 1.5 2001/04/11 23:07:29 pwessel Exp $
+ *    $Id: blockmean.c,v 1.5.4.7 2004/01/02 22:23:10 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -34,6 +34,7 @@
    Modified:	18 Oct 1999 by PW to add -S
    Modified:	3.3.5: 10 Jul 2000 by PW to add -L
    Version:	3.4: 01-MAR-2001 by PW, Use -F instead of -N, and add -C
+   Version:	3.4.3
 */
 
 #include "gmt.h"
@@ -140,7 +141,7 @@ main (int argc, char **argv)
 	if (argc == 1 || GMT_quick) {
 		fprintf (stderr, "blockmean %s - Block averaging by L2 norm\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: blockmean [infile(s)] -I<xinc[m]>[/<yinc>[m]] -R<west/east/south/north>\n");
-		fprintf (stderr, "\t[-C] [-F] [-H[<nrec>]] [-L] [-S] [-V] [-W[i][o] ] [-:] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf (stderr, "\t[-C] [-F] [-H[<nrec>]] [-L] [-S] [-V] [-W[i][o] ] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -213,7 +214,7 @@ main (int argc, char **argv)
 	if ( (set_up_arrays(n_x, n_y, &method) ) ) exit (EXIT_FAILURE);
 	
 	if (gmtdefs.verbose) {
-		sprintf (format, "%%s: W: %s E: %s S: %s N: %s nx: %%d ny: %%d\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%%s: W: %s E: %s S: %s N: %s nx: %%d ny: %%d\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (stderr, format, GMT_program, west, east, south, north, n_x, n_y);
 		if (method) {
 			fprintf (stderr, "%s: Direct method requires %d bytes for array.\n", GMT_program, (n_x*n_y*sizeof(struct WXYZ)));
