@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmedian.c,v 1.5 2001/04/11 23:07:29 pwessel Exp $
+ *    $Id: blockmedian.c,v 1.5.4.7 2004/01/02 22:23:10 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,7 @@
    Modified:	29 Oct 1998 by WHFS to add -Q option
    Modified:	3.3.5: 10 Jul 2000 by PW to add -L
    Version:	3.4 01-MAR-2001 by PW, Use -F instead of -N, and add -C
+   Version:	3.4.3
 */
 
 #include "gmt.h"
@@ -133,7 +134,7 @@ main (int argc, char **argv)
 	if (argc == 1 || GMT_quick) {
 		fprintf (stderr, "blockmedian %s - Block averaging by L1 norm\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: blockmedian [infile(s)] -I<xinc[m]>[/<yinc>[m]] -R<west/east/south/north>\n");
-		fprintf (stderr, "\t[-C] [-F] [-H[<nrec>]] [-L] [-Q] [-V] [-W[i][o] ] [-:] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf (stderr, "\t[-C] [-F] [-H[<nrec>]] [-L] [-Q] [-V] [-W[i][o] ] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -211,7 +212,7 @@ main (int argc, char **argv)
 	xy_off = 0.5 - del_off;
 	
 	if (gmtdefs.verbose) {
-		sprintf (format, "%%s: W: %s E: %s S: %s N: %s nx: %%d ny: %%d\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%%s: W: %s E: %s S: %s N: %s nx: %%d ny: %%d\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (stderr, format, GMT_program, west, east, south, north, n_x, n_y);
 	}
 
