@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: filter1d.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *    $Id: filter1d.c,v 1.2.4.6 2004/01/02 22:23:10 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@
  *
  * Author:	Walter H. F. Smith
  * Date:	13 January, 1989
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -237,7 +237,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "filter1d %s - Time domain filtering of 1-D time series\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: filter1d [infile] -F<type><width> [-D<increment>] [-E]\n");
 		fprintf (stderr, "\t[-H[<nrec>]] [-I<ignore_val>] [-L<lack_width>] [-N<n_cols>/<t_col>]\n");
-		fprintf (stderr, "\t[-Q<q_factor>] [-S<symmetry_factor>] [-T<start>/<stop>/<int>] [-V] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf (stderr, "\t[-Q<q_factor>] [-S<symmetry_factor>] [-T<start>/<stop>/<int>] [-V] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
