@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: fitcircle.c,v 1.3 2001/04/11 23:07:29 pwessel Exp $
+ *    $Id: fitcircle.c,v 1.3.4.6 2004/01/02 22:23:10 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -54,7 +54,7 @@
  *
  * Author:	W. H. F. Smith
  * Date:	16 September 1991.
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
 
@@ -172,7 +172,7 @@ main (int argc, char **argv)
 	n_alloc = GMT_CHUNK;
 	n_data = 0;
 	lonsum = latsum = 0.0;
-	sprintf (format, "%s\t%s\0", gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format, "%s\t%s", gmtdefs.d_format, gmtdefs.d_format);
 	
 	data = (struct DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct DATA), GMT_program);
 
@@ -261,13 +261,13 @@ main (int argc, char **argv)
 				if (greenwich && lonsum < 0.0) lonsum += 360.0;
 				fprintf (GMT_stdout, format, lonsum, latsum);
 				fprintf (GMT_stdout, "\tL1 Small Circle Pole.  ");
-				sprintf(format, "Distance from Pole to L1 Small Circle (degrees):     %s\n\0", gmtdefs.d_format);
+				sprintf(format, "Distance from Pole to L1 Small Circle (degrees):     %s\n", gmtdefs.d_format);
 				fprintf (GMT_stdout, format, rad);
 			}
 		}
 	}
 
-	sprintf (format, "%s\t%s\0", gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format, "%s\t%s", gmtdefs.d_format, gmtdefs.d_format);
 	if (norm/2) {
 
 		n = 3;
@@ -327,7 +327,7 @@ main (int argc, char **argv)
 				if (greenwich && lonsum < 0.0) lonsum += 360.0;
 				fprintf (GMT_stdout, format, lonsum, latsum);
 				fprintf (GMT_stdout, "\tL2 Small Circle Pole.  ");
-				sprintf(format, "Distance from Pole to L2 Small Circle (degrees):     %s\n\0", gmtdefs.d_format);
+				sprintf(format, "Distance from Pole to L2 Small Circle (degrees):     %s\n", gmtdefs.d_format);
 				fprintf (GMT_stdout, format, rad);
 			}
 		}
