@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: fourt.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: fourt.c,v 1.2.4.4 2004/01/02 22:23:10 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -55,7 +55,7 @@ int fourt_ (real *data, integer *nn, integer *ndim, integer *ksign, integer *ifo
 
     /* Builtin functions */
     
-    double cos(double), sin(double);
+    double sin(double);
 
     /* Local variables */
 
