@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt.h,v 1.7 2001/03/22 17:26:33 pwessel Exp $
+ *	$Id: gmt.h,v 1.7.4.9 2004/01/12 01:37:50 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
  * Author:	Paul Wessel
  * Date:	01-MAR-1991
  * Revised:	22-MAR-2001
- * Version:	3.4
+ * Version:	3.4.4
  */
  
 #ifndef _GMT_H
@@ -115,7 +115,7 @@
 #define GMT_CHUNK	2000
 #define GMT_SMALL_CHUNK	50
 #define GMT_TINY_CHUNK	5
-#define GMT_VERSION	"3.4"
+#define GMT_VERSION	"3.4.4"
 #define CNULL		((char *)NULL)
 #define VNULL		((void *)NULL)
 #define GMT_CM		0
@@ -360,7 +360,7 @@ EXTERN_MSC char *GMT_degree_symbol[2];	/* Contains the two octal codes for small
 
 
 EXTERN_MSC FILE *GMT_stdin, *GMT_stdout;
-EXTERN_MSC PFI GMT_input, GMT_output;
+EXTERN_MSC PFI GMT_input, GMT_output, GMT_input_ascii;
 EXTERN_MSC BOOLEAN GMT_geographic_in;	/*TRUE if input data is long/lat */
 EXTERN_MSC BOOLEAN GMT_geographic_out;	/*TRUE if output data is long/lat */
 EXTERN_MSC double GMT_data[BUFSIZ];
