@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_cdf.c,v 1.3 2001/04/11 19:58:09 pwessel Exp $
+ *	$Id: gmt_cdf.c,v 1.3.4.6 2004/01/02 22:23:10 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
  * Author:	Paul Wessel
  * Date:	9-SEP-1992
  * Modified:	13-JAN-2001
- * Version:	3.4
+ * Version:	3.4.3
  *
  * Functions include:
  *
@@ -75,9 +75,15 @@ int GMT_cdf_read_grd_info (char *file, struct GRD_HEADER *header)
         check_nc_status (nc_inq_varid (cdfid, "z", &z_id));
 
 	/* Get attributes */
+	memset ((void *)header->x_units, 0, (size_t)GRD_UNIT_LEN);
+	memset ((void *)header->y_units, 0, (size_t)GRD_UNIT_LEN);
+	memset ((void *)header->z_units, 0, (size_t)GRD_UNIT_LEN);
 	check_nc_status (nc_get_att_text  (cdfid, x_range_id, "units", header->x_units));
         check_nc_status (nc_get_att_text  (cdfid, y_range_id, "units", header->y_units));
 	check_nc_status (nc_get_att_text  (cdfid, z_range_id, "units", header->z_units));
+	if (!header->x_units[0]) strcpy (header->x_units, "user_x_unit");	/* Set defaults if nothing given in file */
+	if (!header->y_units[0]) strcpy (header->y_units, "user_y_unit");
+	if (!header->z_units[0]) strcpy (header->z_units, "user_z_unit");
         check_nc_status (nc_get_att_double  (cdfid, z_id, "scale_factor", &header->z_scale_factor));
         check_nc_status (nc_get_att_double  (cdfid, z_id, "add_offset", &header->z_add_offset));
         check_nc_status (nc_get_att_int  (cdfid, z_id, "node_offset", &header->node_offset));
