@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_customio.c,v 1.4 2001/03/22 17:12:44 pwessel Exp $
+ *	$Id: gmt_customio.c,v 1.4.4.5 2004/01/02 22:23:10 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,7 @@
  * Author:	Paul Wessel
  * Date:	9-SEP-1992
  * Modified:	05-MAR-2001
- * Version:	3.4
+ * Version:	3.4.3
  *
  * Functions include:
  *
