@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_grdio.c,v 1.4 2001/04/11 19:58:09 pwessel Exp $
+ *	$Id: gmt_grdio.c,v 1.4.4.10 2004/01/10 22:00:15 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
  * Author:	Paul Wessel
  * Date:	9-SEP-1992
  * Modified:	27-JUN-2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  * Functions include:
  *
@@ -123,7 +123,8 @@ int GMT_write_grd (char *file, struct GRD_HEADER *header, float *grid, double w,
 
 	GMT_grd_o_format = GMT_grd_get_o_format (file, fname, &scale, &offset);
 	header->z_scale_factor = scale, header->z_add_offset = offset;
-	GMT_grd_do_scaling (grid, (header->nx * header->ny), scale, offset);
+	/* old: GMT_grd_do_scaling (grid, (header->nx * header->ny), scale, offset); */
+	GMT_grd_do_scaling (grid, (header->nx * header->ny), 1.0/scale, -offset/scale);
 	status = (*GMT_io_writegrd[GMT_grd_o_format]) (fname, header, grid, w, e, s, n, pad, complex);
 	return (status);
 }
@@ -143,7 +144,7 @@ void GMT_expand_filename (char *file, char *fname)
 		}
 		if (found) {
 			i--;
-			sprintf (fname, "%s=%d/%lg/%lg/%lg\0", file, GMT_file_id[i], GMT_file_scale[i], GMT_file_offset[i], GMT_file_nan[i]);
+			sprintf (fname, "%s=%d/%lg/%lg/%lg", file, GMT_file_id[i], GMT_file_scale[i], GMT_file_offset[i], GMT_file_nan[i]);
 		}
 		else
 			strcpy (fname, file);
@@ -154,7 +155,7 @@ void GMT_expand_filename (char *file, char *fname)
 
 int GMT_grd_get_i_format (char *file, char *fname, double *scale, double *offset)
 {
-	int i = 0, j, n, id = 0;
+	int i = 0, j, id = 0;
 
 	GMT_expand_filename (file, fname);
 	
@@ -162,9 +163,7 @@ int GMT_grd_get_i_format (char *file, char *fname, double *scale, double *offset
 	
 	if (fname[i]) {	/* Check format id */
 		i++;
-		n = sscanf (&fname[i], "%d/%lf/%lf/%lf", &id, scale, offset, &GMT_grd_in_nan_value);
-/*		if (n <= 1) *scale = GMT_d_NaN, *offset = 0.0;
-		else if (n == 4) GMT_grd_in_nan_value = (GMT_grd_in_nan_value - *offset) / *scale; */
+		sscanf (&fname[i], "%d/%lf/%lf/%lf", &id, scale, offset, &GMT_grd_in_nan_value);
  		if (id < 0 || id >= N_GRD_FORMATS) {
 			fprintf (stderr, "GMT Warning: grdfile format option (%d) unknown, reset to 0\n", id);
 			id = 0;
@@ -177,7 +176,7 @@ int GMT_grd_get_i_format (char *file, char *fname, double *scale, double *offset
 
 int GMT_grd_get_o_format (char *file, char *fname, double *scale, double *offset)
 {
-	int i = 0, j, n, id = 0;
+	int i = 0, j, id = 0;
 
 	GMT_expand_filename (file, fname);
 	
@@ -185,8 +184,7 @@ int GMT_grd_get_o_format (char *file, char *fname, double *scale, double *offset
 	
 	if (fname[i]) {	/* Check format id */
 		i++;
-		n = sscanf (&fname[i], "%d/%lf/%lf/%lf", &id, scale, offset, &GMT_grd_out_nan_value);
-	/*	if (n == 4) GMT_grd_out_nan_value = (GMT_grd_out_nan_value - *offset) / *scale; */
+		sscanf (&fname[i], "%d/%lf/%lf/%lf", &id, scale, offset, &GMT_grd_out_nan_value);
 		if (id < 0 || id >= N_GRD_FORMATS) {
 			fprintf (stderr, "GMT Warning: grdfile format option (%d) unknown, reset to 0\n", id);
 			id = 0;
@@ -297,7 +295,7 @@ int *GMT_grd_prep_io (struct GRD_HEADER *header, double *w, double *e, double *s
 		if (*w < header->x_min || *e > header->x_max) geo = TRUE;	/* Dealing with periodic grid */
 
 		if (*s < header->y_min || *n > header->y_max) {	/* Calling program goofed... */
-			fprintf (stderr, "GMT ERROR: Trying to read beyond grid domain - abort!!\n", GMT_program);
+			fprintf (stderr, "%s: GMT ERROR: Trying to read beyond grid domain - abort!!\n", GMT_program);
 			exit (EXIT_FAILURE);
 		}
 		one_or_zero = (header->node_offset) ? 0 : 1;
@@ -346,7 +344,7 @@ int *GMT_grd_prep_io (struct GRD_HEADER *header, double *w, double *e, double *s
 void GMT_decode_grd_h_info (char *input, struct GRD_HEADER *h) {
 
 /*	Given input string, copy elements into string portions of h.
-	Replace underscores by blanks.  Use "/" as the field separator.
+	Use "/" as the field separator.
 	If a field has an equals sign, skip it.
 	This routine is usually called if -D<input> was given by user,
 	and after GMT_grd_init() has been called.
@@ -354,9 +352,6 @@ void GMT_decode_grd_h_info (char *input, struct GRD_HEADER *h) {
 	char	*ptr;
 	int	entry;
 	
-	/* Replace blanks  */	
-	for (entry = 0; input[entry]; entry++) if (input[entry] == '_') input[entry] = ' ';
-	
 	ptr = strtok (input, "/");
 	entry = 0;
 	while (ptr) {
