@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_grdio.h,v 1.3 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: gmt_grdio.h,v 1.3.4.5 2004/01/02 22:23:10 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
  * Author:	Paul Wessel
  * Date:	21-AUG-1995
  * Revised:	10-SEP-1999
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #ifndef GMT_GRDIO_H
