@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_io.c,v 1.3 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: gmt_io.c,v 1.3.4.7 2004/01/02 22:23:10 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -68,7 +68,7 @@
  *
  * Author:	Paul Wessel
  * Date:	14-JUL-2000
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -124,7 +124,7 @@ void GMT_io_init (void)
 {
 	/* No need to init the structure as this is done in gmt_init.h directoy */
 	
-	GMT_input = GMT_ascii_input;
+	GMT_input = GMT_input_ascii = GMT_ascii_input;
 	GMT_output = GMT_ascii_output;
 
 	GMT_io.give_report = TRUE;
@@ -491,7 +491,8 @@ int GMT_bin_float_output (FILE *fp, int n, double *ptr)
 
 void GMT_write_segmentheader (FILE *fp, int n)
 {
-	/* Output ASCII or binary multisegment header */
+	/* Output ASCII or binary multisegment header.
+	 * ASCII header is expected to contain newline (\n) */
 
 	int i;
 	if (GMT_io.binary[1])
