@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_map.h,v 1.3 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: gmt_map.h,v 1.3.4.5 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
  * of latitudes used in GMT
  *
  * W H F Smith, 10--13 May 1999.
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #define GMT_LATSWAP_G2A 0	/* input = geodetic;   output = authalic   */
