@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_project.h,v 1.4 2001/03/07 17:51:41 pwessel Exp $
+ *	$Id: gmt_project.h,v 1.4.4.5 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
  * Author:	Paul Wessel
  * Date:	26-FEB-1990
  * Revised:	24-MAR-2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
 #ifndef _GMT_PROJECT_H
