@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_shore.c,v 1.3 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: gmt_shore.c,v 1.3.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -38,7 +38,7 @@
  *
  * Author:	Paul Wessel
  * Date:	13-JUN-2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
 
@@ -100,7 +100,7 @@ int GMT_init_shore (char res, struct GMT_SHORE *c, double w, double e, double s,
 	size_t start[1], count[1];
 	char file[32], path[BUFSIZ];
 	
-	sprintf (file, "binned_GSHHS_%c.cdf\0", res);
+	sprintf (file, "binned_GSHHS_%c.cdf", res);
 	
         if (!GMT_getpathname (file, path)) return (-1);	/* Failed to find file */
         
@@ -284,9 +284,9 @@ int GMT_init_br (char which, char res, struct GMT_BR *c, double w, double e, dou
 	char file[32], path[BUFSIZ];
 	
 	if (which == 'r')
-		sprintf (file, "binned_river_%c.cdf\0", res);
+		sprintf (file, "binned_river_%c.cdf", res);
 	else
-		sprintf (file, "binned_border_%c.cdf\0", res);
+		sprintf (file, "binned_border_%c.cdf", res);
 	
         if (!GMT_getpathname (file, path)) return (-1);	/* Failed to find file */
 
