@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_stat.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: gmt_stat.c,v 1.2.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  *
  * Author:	Walter H. F. Smith
  * Date:	12-JUN-1995
- * Version:	3.4
+ * Version:	3.4.3
  * Revised:	12-AUG-1998
  *		06-JAN-1999 P Wessel: Added GMT_ber, GMT_bei, GMT_ker, GMT_kei
  *		12-JAN-1999 P Wessel: Added GMT_plm
@@ -1645,7 +1645,7 @@ void sincos (double a, double *s, double *c)
 #define GMT_RAND_NDIV (1 + (GMT_RAND_IM - 1) / GMT_RAND_NTAB)
 #define GMT_RAND_EPS 2.2204460492503131E-16
 
-double GMT_rand ()
+double GMT_rand (void)
 {
 	/* Uniform random number generator based on ran1 of
 	 * Press et al, Numerical Recipes, 2nd edition,
@@ -1695,7 +1695,7 @@ double GMT_nrand (void) {
 	static int iset = 0;
 	static double gset;
 	double fac, r, v1, v2;
-	double GMT_rand ();
+	double GMT_rand (void);
 
 	if (iset == 0) {	/* We don't have an extra deviate handy, so */
 		do {
