@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_vector.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: gmt_vector.c,v 1.2.4.5 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 /*
  * Author:	Walter H.F. Smith
  * Date:	12-JUL-2000
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
