@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtconvert.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: gmtconvert.c,v 1.2.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
   
    Author: 	P. Wessel
    Date:	13-JUL-2000.
-   version:	3.4
+   version:	3.4.3
 
 */
 
@@ -75,7 +75,7 @@ main (int argc, char **argv)
 	
 	if (argc == 1 || GMT_quick) {
 		fprintf (stderr, "gmtconvert %s - gmtconvert table data from one format to another\n\n", GMT_VERSION);
-		fprintf(stderr,"usage:	gmtconvert [files] [-H[<nrec>]] [-M[<flag>]] [-V] [-:] [-bi[s]<n>] [-bo[s]]\n\n");
+		fprintf(stderr,"usage:	gmtconvert [files] [-H[<nrec>]] [-M[<flag>]] [-V] [-:] [-bi[s]<n>] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 
