@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtdefaults.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: gmtdefaults.c,v 1.3.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
  *
  * Author:	Paul Wessel
  * Date:	12-JUL-2000
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -34,6 +34,9 @@ main (int argc, char **argv)
 	
 	char *path;
 	
+	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
+	GMT_program = &argv[0][i+1];	/* Name without full path */
+
 	GMT_stdout = stdout;	GMT_stdin = stdin;
 
 	for (i = 1; !error && i < argc; i++) {
