@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtmath_main.c,v 1.4 2001/04/11 19:58:09 pwessel Exp $
+ *	$Id: gmtmath_main.c,v 1.4.4.9 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -36,6 +36,7 @@
  *		3.3.6 PW 08/18/00 Added -S to just return first row
  *		3.3.6 PW 08/23/00 Added LOWER and UPPER
  *		3.4   PW 03/01/01
+ *		3.4.3
  *
  */
  
@@ -58,7 +59,7 @@ PFV call_operator[N_OPERATORS];
 
 int nm = 0, consumed_operands[N_OPERATORS], produced_operands[N_OPERATORS];
 
-struct GMT_HASH hashnode[HASH_SIZE];
+struct GMT_HASH localhashnode[HASH_SIZE];
 
 double *t_coordinates;
 
@@ -115,7 +116,7 @@ main (int argc, char **argv)
 	if (argc == 1 || GMT_quick) {
 		fprintf (stderr, "gmtmath %s - Reverse Polish Notation (RPN) calculator for table data\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: gmtmath [-C<cols>] [-H[<nrec>]] [-N<n_col>/<t_col>] [-Q] [-S] [-T[<tmin/tmax/t_inc>]]\n");
-		fprintf (stderr, "\t[-bi[d][<n>]] [-bo[d]] [-V] A B op C op ... = [outfile]\n\n");
+		fprintf (stderr, "\t[-bi[s][<n>]] [-bo[s][<n>]] [-V] A B op C op ... = [outfile]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -164,7 +165,7 @@ main (int argc, char **argv)
 			fprintf (stderr, "%s Warning: Your file %s may be confused with a %s operator!\n", GMT_program, special_arg[i], GMT_program);
 	}
 
-	GMT_hash_init (hashnode, operator, HASH_SIZE, N_OPERATORS);
+	GMT_hash_init (localhashnode, operator, HASH_SIZE, N_OPERATORS);
 
 	for (i = 0; i < STACK_SIZE; i++) {
 		constant[i] = FALSE;
@@ -287,7 +288,7 @@ main (int argc, char **argv)
 
 	t_coordinates = (double *) GMT_memory (VNULL, (size_t)header.n_row, sizeof (double), GMT_program);
 	for (i = 0; i < header.n_row; i++) t_coordinates[i] = (i == (header.n_row-1)) ? header.t_max: header.t_min + i * header.t_inc;
-	t_noise = SMALL * header.t_inc;
+	t_noise = fabs (SMALL * header.t_inc);
 	memcpy ((void *)stack[0][t_col], (void *)t_coordinates, (size_t)(header.n_row * sizeof (double)));
 
 	gmtmath_init (call_operator, consumed_operands, produced_operands);
@@ -423,7 +424,10 @@ main (int argc, char **argv)
 	if (gmtdefs.verbose) fprintf (stderr, "= %s", outfile);
 
 	if (new_stack < 0 && constant[0]) {	/* Only a constant provided, set grid accordingly */
-		for (j = 0; j < header.n_col; j++) for (i = 0; i < header.n_row; i++) stack[0][j][i] = factor[0];
+		for (j = 0; j < header.n_col; j++) {
+			if (skip[j]) continue;
+			for (i = 0; i < header.n_row; i++) stack[0][j][i] = factor[0];
+		}
 	}
 
 	if (one_row_out) header.n_row = 1;	/* Trick to get only the first row on output */
@@ -855,8 +859,10 @@ void table_DIV (double **stack[], BOOLEAN *constant, double *factor, int last, i
 		exit (EXIT_FAILURE);
 	}
 	if (constant[last]) {	/* Turn divide into multiply */
+		a = factor[last];	/* Save old factor */
 		factor[last] = 1.0 / factor[last];
 		table_MUL (stack, constant, factor, last, col, n_row);
+		factor[last] = a;	/* Restore factor to original value */
 		return;
 	}
 	
@@ -1252,7 +1258,7 @@ void table_LMSSCL (double **stack[], BOOLEAN *constant, double *factor, int last
 	}
 
 	qsort ((void *)stack[last][col], (size_t)n_row, sizeof (double), GMT_comp_double_asc);
-	for (i = n_row-1; GMT_is_fnan (stack[last][col][i]) && i > 0; i--);
+	for (i = n_row; GMT_is_fnan (stack[last][col][i-1]) && i > 1; i--);
 	if (i) {
 		GMT_mode (stack[last][col], i, i/2, 0, &mode);
 		GMT_getmad (stack[last][col], i, mode, &lmsscl);
@@ -1337,7 +1343,7 @@ void table_MAD (double **stack[], BOOLEAN *constant, double *factor, int last, i
 	}
 
 	qsort ((void *)stack[last][col], (size_t)n_row, sizeof (double), GMT_comp_double_asc);
-	for (i = n_row-1; GMT_is_fnan (stack[last][col][i]) && i > 0; i--);
+	for (i = n_row; GMT_is_fnan (stack[last][col][i-1]) && i > 1; i--);
 	if (i) {
 		med = (i%2) ? stack[last][col][i/2] : 0.5 * (stack[last][col][(i-1)/2] + stack[last][col][i/2]);
 		GMT_getmad (stack[last][col], i, med, &mad);
@@ -1391,7 +1397,7 @@ void table_MED (double **stack[], BOOLEAN *constant, double *factor, int last, i
 	}
 
 	qsort ((void *)stack[last][col], (size_t)n_row, sizeof (double), GMT_comp_double_asc);
-	for (i = n_row-1; GMT_is_fnan (stack[last][col][i]) && i > 0; i--);
+	for (i = n_row; GMT_is_fnan (stack[last][col][i-1]) && i > 1; i--);
 	if (i)
 		med = (i%2) ? stack[last][col][i/2] : 0.5 * (stack[last][col][(i-1)/2] + stack[last][col][i/2]);
 	else
@@ -1424,7 +1430,7 @@ void table_MODE (double **stack[], BOOLEAN *constant, double *factor, int last,
 	}
 
 	qsort ((void *)stack[last][col], (size_t)n_row, sizeof (double), GMT_comp_double_asc);
-	for (i = n_row-1; GMT_is_fnan (stack[last][col][i]) && i > 0; i--);
+	for (i = n_row; GMT_is_fnan (stack[last][col][i-1]) && i > 1; i--);
 	if (i)
 		GMT_mode (stack[last][col], i, i/2, 0, &mode);
 	else
@@ -1927,7 +1933,7 @@ char *choice; {
 	
 	/* Returns -1 if not a registered operator */
 
-	op = GMT_hash_lookup (choice, hashnode, HASH_SIZE);
+	op = GMT_hash_lookup (choice, localhashnode, HASH_SIZE);
 
 	if (op < 0 && strlen (choice) == 1) {	/* Check for old-style operators */
 	
