@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtselect.c,v 1.5 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: gmtselect.c,v 1.5.4.10 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -44,7 +44,7 @@
  *				 	suggested by Joaquim Luis.
  *		3.3.4 17-FEB-2000.	Polygons containing either S or N pole will work correctly
  *		3.3.5 10-JUL-2000	Added plain -L for periodicity
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -87,7 +87,7 @@ main (int argc, char **argv)
 	int i, j, k, fno, n_read = 0, n_pass = 0, n_files = 0, n_args, n_points, n_lines, n_pols;
 	int n_fields, n_expected_fields, out_edge_in[5], ind, bin, last_bin = -1;
 	int min_level = 0, max_level = MAX_LEVEL, np[2], base = 3, wd[2], id, this_node;
-	int side, is_inside = 1, row, col;
+	int side, is_inside = 1, row, col, n_output = -1;
 
 	
 	BOOLEAN error = FALSE, limit_line_distance = FALSE, limit_polygon = FALSE, limit_point_distance = FALSE, limit_point_distance_cart = FALSE;
@@ -245,7 +245,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "gmtselect %s - Select data subsets based on multiple spatial criteria\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: gmtselect <infiles> [-A<min_area>[/<min_level>/<max_level>]] [-C[f]<dist>/<ptfile>] [-D<resolution>]\n");
 		fprintf (stderr, "\t[-F<polygon>] [-J<parameters>] [-L[<dist>/<lfile>]] [-H[<nrec>]] [-I[cflrs]\n");
-		fprintf (stderr, "\t[-M[<flag>]]  [-N<maskvalues>[o]] [-R<west/east/south/north>] [-V] [-:] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf (stderr, "\t[-M[<flag>]]  [-N<maskvalues>[o]] [-R<west/east/south/north>] [-V] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -447,7 +447,7 @@ main (int argc, char **argv)
 			}
 			first = FALSE;
 		}
-		n_expected_fields = (GMT_io.ncol[0]) ? GMT_io.ncol[0] : 2;
+		n_expected_fields = (GMT_io.ncol[0]) ? GMT_io.ncol[0] : BUFSIZ;
 	
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && ! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
@@ -577,8 +577,10 @@ main (int argc, char **argv)
 
 			/* Here, we have passed all test and the point is output */
 
-			if (binary)
-				GMT_output (GMT_stdout, n_expected_fields, in);
+			if (binary) {
+				if (n_output < 0) n_output = n_expected_fields;
+				GMT_output (GMT_stdout, n_output, in);
+			}
 			else
 				fprintf (GMT_stdout, "%s", GMT_io.current_record);
 			n_pass++;
@@ -614,10 +616,10 @@ int points_init (char *file, double **xp, double **yp, double **dp, double dist,
 		exit (EXIT_FAILURE);
 	}
 
-	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && ! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
+	while ((n_fields = GMT_input_ascii (fp, &n_expected_fields, &in)) >= 0 && ! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
 		while (GMT_io.status & GMT_IO_SEGMENT_HEADER && !(GMT_io.status & GMT_IO_EOF)) {
-			n_fields = GMT_input (fp, &n_expected_fields, &in);
+			n_fields = GMT_input_ascii (fp, &n_expected_fields, &in);
 		}
 		if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
 
@@ -686,7 +688,7 @@ int lines_init (char *file, struct LINES **p, double dist, BOOLEAN greenwich)
 	save = GMT_io.multi_segments;	/* Must set this to TRUE temporarily */
 	GMT_io.multi_segments = TRUE;
 	
-	n_fields = GMT_input (fp, &n_expected_fields, &in);
+	n_fields = GMT_input_ascii (fp, &n_expected_fields, &in);
 	if (GMT_io.status & GMT_IO_EOF) {
 		fprintf (stderr, "%s: File %s is empty!\n", GMT_program, file);
 		exit (EXIT_FAILURE);
@@ -706,7 +708,7 @@ int lines_init (char *file, struct LINES **p, double dist, BOOLEAN greenwich)
 			j_alloc = GMT_CHUNK;
 			j = 0;
 			lon_sum = 0.0;
-			n_fields = GMT_input (fp, &n_expected_fields, &in);
+			n_fields = GMT_input_ascii (fp, &n_expected_fields, &in);
 		}
 		if ((GMT_io.status & GMT_IO_EOF)) continue;	/* At EOF */
 		
@@ -742,7 +744,7 @@ int lines_init (char *file, struct LINES **p, double dist, BOOLEAN greenwich)
 				e[i].lon = (double *) GMT_memory ((void *)e[i].lon, (size_t)j_alloc, sizeof (double), GMT_program);
 				e[i].lat = (double *) GMT_memory ((void *)e[i].lat, (size_t)j_alloc, sizeof (double), GMT_program);
 			}
-			n_fields = GMT_input (fp, &n_expected_fields, &in);
+			n_fields = GMT_input_ascii (fp, &n_expected_fields, &in);
 		}
 		e[i].np = j;
 
@@ -783,6 +785,10 @@ int near_a_line (double lon, double lat, struct LINES *p, int np)
 	double d_min, dx, xc, yc, a, a_inv, d;
 
 	while (i < np && !inside) {
+		if (p[i].np < 2) {	/* empty or 1-point "line"; skip */
+			i++;
+			continue;
+		}
 
 		/* Find nearest point on this line */
 
