@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtset.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: gmtset.c,v 1.3.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  *
  * Author:	Paul Wessel
  * Date:	10-JUN-2000
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -35,7 +35,7 @@ main (int argc, char **argv)
 	
 	if (argc == 1 || GMT_quick) {
 		fprintf (stderr, "gmtset %s - To set individual default parameters\n\n", GMT_VERSION);
-		fprintf (stderr, "usage: gmtset [-G<defaultsfile> PARAMETER1 [=] value1 PARAMETER2 [=] value2 PARAMETER3 [=] value3 ...\n");
+		fprintf (stderr, "usage: gmtset [-G<defaultsfile>] PARAMETER1 [=] value1 PARAMETER2 [=] value2 PARAMETER3 [=] value3 ...\n");
 		fprintf (stderr, "\tFor available PARAMETERS, see gmtdefaults man page\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
