@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grd2cpt.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grd2cpt.c,v 1.3.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,7 @@
  * Revised:	PW: 12-MAY-1998, for GMT 3.1
  *		PW: 08-MAR-1998, for GMT 3.2 to allow use of master cptfiles
  *		PW: 08-JUL-2000, for GMT 3.3.5
- * Version:	3.4
+ * Version:	3.4.3
  * 
  */
 
@@ -64,7 +64,7 @@ main (int argc, char **argv)
 
 	/* Get list of available color tables in GMT /share */
 
-	sprintf (CPT_lis, "%s%cshare%cGMT_CPT.lis\0", GMTHOME, DIR_DELIM, DIR_DELIM);
+	sprintf (CPT_lis, "%s%cshare%cGMT_CPT.lis", GMTHOME, DIR_DELIM, DIR_DELIM);
 
 	if ((fpc = fopen (CPT_lis, "r")) == NULL) {
 		fprintf (stderr, "%s: ERROR: Cannot open file %s\n", GMT_program, CPT_lis);
@@ -172,7 +172,7 @@ main (int argc, char **argv)
 		if (strstr (table, ".cpt"))
 			strcpy (CPT_file, table);
 		else
-			sprintf (CPT_file, "%s.cpt\0", table);
+			sprintf (CPT_file, "%s.cpt", table);
 
 		ok = !access (CPT_file, R_OK);
 		if (ok && gmtdefs.verbose) fprintf (stderr, "%s: Reading %s in current directory\n", GMT_program, CPT_file);
@@ -180,9 +180,9 @@ main (int argc, char **argv)
 
 	if (!ok)	{	/* No table in current dir, try /share */
 		if (table)
-			sprintf (CPT_file, "%s%cshare%cGMT_%s.cpt\0", GMTHOME, DIR_DELIM, DIR_DELIM, table);
+			sprintf (CPT_file, "%s%cshare%cGMT_%s.cpt", GMTHOME, DIR_DELIM, DIR_DELIM, table);
 		else	/* Default to rainbow colors */
-			sprintf (CPT_file, "%s%cshare%cGMT_rainbow.cpt\0", GMTHOME, DIR_DELIM, DIR_DELIM);
+			sprintf (CPT_file, "%s%cshare%cGMT_rainbow.cpt", GMTHOME, DIR_DELIM, DIR_DELIM);
 
 		if (access (CPT_file, R_OK)) {
 			fprintf (stderr, "%s: ERROR: Cannot find colortable %s\n", GMT_program, CPT_file);
@@ -252,7 +252,7 @@ main (int argc, char **argv)
 	sd /= ngood;
 	sd = sqrt(sd - mean*mean);
 	if (gmtdefs.verbose) {
-		sprintf(format,"%%s:  Mean and S.D. of data are %s %s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+		sprintf(format,"%%s:  Mean and S.D. of data are %s %s\n", gmtdefs.d_format, gmtdefs.d_format);
 		fprintf(stderr, format, GMT_program, mean, sd);
 	}
 
@@ -311,7 +311,7 @@ main (int argc, char **argv)
 
 	/* Get here when we are ready to go.  cdf_cpt[].z contains the sample points.  */
 
-	if (gmtdefs.verbose) sprintf (format, "%%s: z = %s and CDF(z) = %s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+	if (gmtdefs.verbose) sprintf (format, "%%s: z = %s and CDF(z) = %s\n", gmtdefs.d_format, gmtdefs.d_format);
 	for (j = 0; j < ncdf; j++) {
 		if (cdf_cpt[j].z <= grd.z_min)
 			cdf_cpt[j].f = 0.0;
