@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grd2xyz.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grd2xyz.c,v 1.3.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
  *
  * Author:	Paul Wessel
  * Date:	3-JAN-1991
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -87,7 +87,7 @@ main (int argc, char **argv)
 	
 	if (argc == 1 || GMT_quick) {
 		fprintf (stderr, "grd2xyz %s - Converting a netCDF grdfile to an ASCII xyz-file\n\n", GMT_VERSION);
-		fprintf( stderr, "usage: grd2xyz grdfile [-H[<nrec>]] [-L] [-Rw/e/s/n] [-S[r]] [-V] [-Z[<flags>]] [-:] [-bo[s]] > xyzfile\n");
+		fprintf( stderr, "usage: grd2xyz grdfile [-H[<nrec>]] [-L] [-Rw/e/s/n] [-S[r]] [-V] [-Z[<flags>]] [-:] [-bo[s][<n>]] > xyzfile\n");
 
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
