@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdclip.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: grdclip.c,v 1.2.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
    Modified for v2.0 4/26/91 P.Wessel
    Modified for v3.1 4/29/98 P.Wessel
    Modified for v3.3.5 06/29/2000 P.Wessel
-   Version:	3.4
+   Version:	3.4.3
  
  */
 
@@ -174,7 +174,7 @@ main (int argc, char **argv)
 	GMT_free ((void *) data);
 
 	if (gmtdefs.verbose) {
-		sprintf (format, "%s set to %s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%s set to %s\n", gmtdefs.d_format, gmtdefs.d_format);
 		if (set_below) {
 			fprintf (stderr, "%s: %d values < ", GMT_program, n_below);
 			fprintf (stderr, format, (double)low, (double)below);
