@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcontour.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grdcontour.c,v 1.3.4.10 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,7 @@
  * Revised:	25-FEB-2000 for GMT 3.3.4
  * Revised:	25-JUN-2000 for GMT 3.3.5
  * Version:	3.4 Added Kaj Jancke's modification for transparent label boxes
+ * Version:	3.4.3
  *
  */
 
@@ -59,13 +60,10 @@ struct SAVE {
 	BOOLEAN do_it, high;
 } *save;
 
-void dump_contour (double *xx, double *yy, int nn, double cval, int id, BOOLEAN interior, char *file);
 void draw_contour (double *xx, double *yy, int nn, double cval, char ctype, double cangle, int closed, double gap, int half_width, char *unit, int box, int label_font_size);
 void sort_and_plot_ticks (struct SAVE *save, int n, struct GRD_HEADER *h, float *grd, double tick_gap, double tick_length, BOOLEAN tick_low, BOOLEAN tick_high, BOOLEAN tick_label, char *labels);
 void plot_labels (int size, int box, int rgb[]);
 
-int int_cont_count = 0, ext_cont_count = 0;
-
 main (int argc, char **argv)
 {
 	int i, j, k, n, nm, c, n_edges, label_font_size = 9, b_rgb[3], n_alloc;
@@ -269,7 +267,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "usage: grdcontour <grdfile> -C<cont_int> -J<params> [-A[-][<anot_int>][f<fontsize>][/r/g/b][a<angle>][o]]\n");
 		fprintf (stderr, "\t[-B<tickinfo>] [-D<dumpfile>] [-Eaz/el] [-G<gap>[c|i|m|p]/<npoints>] [-K] [-L<Low/high>]\n");
 		fprintf (stderr, "\t[-M[<flag>]] [-N[unit]] [-O] [-P] [-Q<cut>] [-R<west/east/south/north>] [-S<smooth>] [-T[+|-][<gap>[c|i|m|p]/<length>[c|i|m|p]][:LH]] [-U[<label>]] [-V]\n");
-		fprintf (stderr, "\t[-W[+]<type><pen>] [-X<x_shift>] [-Y<y_shift>] [-Z[<fact>[/shift>]][p]] [-bo[s]] [-c<ncopies>]\n\n");
+		fprintf (stderr, "\t[-W[+]<type><pen>] [-X<x_shift>] [-Y<y_shift>] [-Z[<fact>[/shift>]][p]] [-bo[s][<n>]] [-c<ncopies>]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -404,7 +402,16 @@ main (int argc, char **argv)
 
 	/* Determine the wesn to be used to read the grdfile */
 
-	GMT_grd_setregion (&header, &data_west, &data_east, &data_south, &data_north);
+	if (GMT_grd_setregion (&header, &data_west, &data_east, &data_south, &data_north)) {	/* No grid to plot; just do empty map and exit */
+		ps_plotinit (CNULL, gmtdefs.overlay, gmtdefs.page_orientation, gmtdefs.x_origin, gmtdefs.y_origin,
+			gmtdefs.global_x_scale, gmtdefs.global_y_scale, gmtdefs.n_copies,
+			gmtdefs.dpi, GMT_INCH , gmtdefs.paper_width, gmtdefs.page_rgb, GMT_epsinfo (argv[0]));
+		GMT_echo_command (argc, argv);
+		if (gmtdefs.unix_time) GMT_timestamp (argc, argv);
+		GMT_map_basemap ();
+		ps_plotend (gmtdefs.last_page);
+		GMT_end (argc, argv);
+	}
 
 	/* Read data */
 
@@ -570,7 +577,7 @@ main (int argc, char **argv)
 				}
 				else
 					interior = FALSE;
-				if (dump && n >= ncut) dump_contour (x, y, n, cval, section, interior, dfile);
+				if (dump && n >= ncut) GMT_dump_contour (x, y, n, cval, section, interior, dfile);
 				if (n >= ncut) draw_contour (x, y, n, cval, cont_type[c], cont_angle[c], interior, anot_dist, half, c_unit, box, label_font_size);
 				if (cont_do_tick[c] && interior && n >= ncut) {
 					save[n_save].x = (double *) GMT_memory (VNULL, (size_t)n, sizeof (double), GMT_program);
@@ -641,50 +648,6 @@ main (int argc, char **argv)
 	GMT_end (argc, argv);
 }
 
-void dump_contour (double *xx, double *yy, int nn, double cval, int id, BOOLEAN interior, char *file)
-{
-	int i;
-	char fname[BUFSIZ], format[80], suffix[4];
-	double out[3];
-	FILE *fp;
-	
-	if (nn < 2) return;
-	
-	out[2] = cval;
-	(GMT_io.binary[1]) ? strcpy (suffix, "b") : strcpy (suffix, "xyz");
-	sprintf (format, "%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
-	if (!GMT_io.binary[1] && GMT_io.multi_segments) {
-		if (GMT_io.multi_segments == 2) {	/* Must create file the first time around */
-			fp = GMT_fopen (file, "w");
-			GMT_io.multi_segments = TRUE;
-		}
-		else	/* Later we append to it */
-			fp = GMT_fopen (file, "a+");
-		sprintf (GMT_io.segment_header, "%c %lg contour\n\0", GMT_io.EOF_flag, cval);
-		GMT_write_segmentheader (fp, 3);
-	}
-	else {
-		if (interior) {
-			if (file[0] == '-')	/* Running numbers only */
-				sprintf (fname, "C%d_i.%s\0", int_cont_count++, suffix);
-			else
-				sprintf (fname, "%s_%lg_%d_i.%s\0", file, cval, id, suffix);
-		}
-		else {
-			if (file[0] == '-')	/* Running numbers only */
-				sprintf (fname, "C%d_e.%s\0", ext_cont_count++, suffix);
-			else
-				sprintf (fname, "%s_%lg_%d.%s\0", file, cval, id, suffix);
-		}
-		fp = GMT_fopen (fname, GMT_io.w_mode);
-	}
-	for (i = 0; i < nn; i++) {
-		out[0] = xx[i];	out[1] = yy[i];
-		GMT_output (fp, 3, out);
-	}
-	GMT_fclose (fp);
-}
-
 void draw_contour (double *xx, double *yy, int nn, double cval, char ctype, double cangle, int closed, double gap, int half_width, char *unit, int box, int label_font_size)
 {
 	int i, j, start = 0;
@@ -695,7 +658,7 @@ void draw_contour (double *xx, double *yy, int nn, double cval, char ctype, doub
 	
 	if (nn < 2) return;
 		
-	sprintf (format, "%lg contour\0", cval);
+	sprintf (format, "%lg contour", cval);
 	ps_comment (format);
 	
 	GMT_n_plot = GMT_geo_to_xy_line (xx, yy, nn);
@@ -758,7 +721,8 @@ void draw_contour (double *xx, double *yy, int nn, double cval, char ctype, doub
 					GMT_plot_line (&GMT_x_plot[start], &GMT_y_plot[start], &GMT_pen[start], i-j-start); 
 					start = i + 1;
 	   				while ( (GMT_x_plot[start] > (x - label_width)) && (GMT_x_plot[start] < (x + label_width)) &&
-	                      	 	 (GMT_y_plot[start] > (y - label_height)) && (GMT_y_plot[start] < (y + label_height))) start++;
+	                      	 		(GMT_y_plot[start] > (y - label_height)) && (GMT_y_plot[start] < (y + label_height))) start++;
+					GMT_pen[start] = 3;	/* Since we may have moved up a bit */
 				}
 			}
 			GMT_x_plot[i-1] = GMT_x_plot[i];	GMT_y_plot[i-1] = GMT_y_plot[i];
