@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcut.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grdcut.c,v 1.3.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
  *
  * Author:	Walter Smith
  * Date:	5 august, 1988
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
  
@@ -128,6 +128,25 @@ main (int argc, char **argv)
 	test_header.y_min = s_new;	test_header.y_max = n_new;	test_header.y_inc = header.y_inc;
 	GMT_grd_RI_verify (&test_header, 1);
 
+	/* OK, so far so good. Check if new wesn differs from old wesn by integer dx/dy */
+	
+	if (GMT_minmaxinc_verify (header.x_min, w_new, header.x_inc, SMALL) == 1) {
+		fprintf (stderr, "%s: Old and new x_min do not differ by N * dx\n", GMT_program);
+		exit (EXIT_FAILURE);
+	}
+	if (GMT_minmaxinc_verify (e_new, header.x_max, header.x_inc, SMALL) == 1) {
+		fprintf (stderr, "%s: Old and new x_max do not differ by N * dx\n", GMT_program);
+		exit (EXIT_FAILURE);
+	}
+	if (GMT_minmaxinc_verify (header.y_min, s_new, header.y_inc, SMALL) == 1) {
+		fprintf (stderr, "%s: Old and new y_min do not differ by N * dy\n", GMT_program);
+		exit (EXIT_FAILURE);
+	}
+	if (GMT_minmaxinc_verify (n_new, header.y_max, header.y_inc, SMALL) == 1) {
+		fprintf (stderr, "%s: Old and new y_max do not differ by N * dy\n", GMT_program);
+		exit (EXIT_FAILURE);
+	}
+
 	GMT_grd_init (&header, argc, argv, TRUE);
 
 	w_old = header.x_min;	e_old = header.x_max;
@@ -144,7 +163,7 @@ main (int argc, char **argv)
 	}
 
 	if (gmtdefs.verbose) {
-		sprintf (format, "\t%s\t%s\t%s\t%s\t%s\t%s\t%%d\t%%d\n\0", gmtdefs.d_format, gmtdefs.d_format,
+		sprintf (format, "\t%s\t%s\t%s\t%s\t%s\t%s\t%%d\t%%d\n", gmtdefs.d_format, gmtdefs.d_format,
 			gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (stderr, "%s: File spec:\tW E S N dx dy nx ny:\n", GMT_program);
 		fprintf (stderr, "%s: Old:", GMT_program);
