@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdedit.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grdedit.c,v 1.3.4.5 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,8 +27,8 @@
  *
  * Author:	Paul Wessel
  * Date:	9-SEP-1998
- * Version:	3.4
  * Modified:	19-FEB-2000 PW: Added -V option
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
