@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdfft.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: grdfft.c,v 1.2.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@
  *   Note to myself:  users want azimuthal power spectra, and
  *   cross-spectra between two grids.  --whfs
  *
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -952,7 +952,7 @@ void	do_spectrum(double *par, int give_wavelength)
 	/* Now get here when array is summed.  */
 	eps_pow = 1.0/sqrt((double)nused/(double)nk);
 	delta_k /= (2.0*M_PI);	/* Write out frequency, not wavenumber  */
-	sprintf (format, "%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format, "%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 	powfactor = 4.0 / pow ((double)ndatac, 2.0);
 	for (k = 0; k < nk; k++) {
 		freq = (k + 1) * delta_k;
