@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdfilter.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: grdfilter.c,v 1.2.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,7 @@
  *		PW: 02-Jun-1999 upgrade to GMT 3.3 + added SINCOS option
  *		PW: 18-Oct-1999 Use sincos directly
  *		PW: 18-JUN-2000 3.3.5
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -208,6 +208,8 @@ main (int argc, char **argv)
 	if (toggle) {	/* Make output grid of the opposite registration */
 		one_or_zero = (h.node_offset) ? 1 : 0;
 	}
+	else
+		one_or_zero = (h.node_offset) ? 0 : 1;
 	
 	/* Read the input grd file and close it  */
 	
