@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdgradient.c,v 1.4 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grdgradient.c,v 1.4.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -40,7 +40,7 @@
  *		11 Sep 97 by PW now may pass average gradient along with sigma in -N
  *		22 Apr 98 by WHFS to add boundary conditions, switch sense of -S and 
  *			-D, and switch -Da to -Dc, for consistency of args.
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -395,7 +395,7 @@ main (int argc, char **argv)
 		else {
 			strcpy (header.title, "Directional derivative(s)");
 		}
-		sprintf (format, "\t%s\t%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "\t%s\t%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		if (gmtdefs.verbose) {
 			fprintf (stderr, "%s:  Min Mean Max sigma intensities:", GMT_program);
 			fprintf (stderr, format, min_gradient, ave_gradient, max_gradient, sigma);
