@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdhisteq.c,v 1.4 2001/04/11 19:58:09 pwessel Exp $
+ *	$Id: grdhisteq.c,v 1.4.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -38,7 +38,7 @@
  * Updated to v2.0 15-May-1991 Paul Wessel
  * Updated to v3.1 14-Jun-1998 Paul Wessel
  * Updated to v3.3.5 14-Jun-2000 Paul Wessel
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -164,7 +164,7 @@ void do_usual (char *infile, char *outfile, int n_cells, int quadratic, int dump
 	int	nxy, nxy_0, current_cell;
 	char format[BUFSIZ];
 	
-	sprintf (format, "%s\t%s\t%%d\n\0", gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format, "%s\t%s\t%%d\n", gmtdefs.d_format, gmtdefs.d_format);
 	
 	if (GMT_read_grd_info (infile, &header)) {
                 fprintf (stderr, "%s: GMT SYNTAX ERROR:  File %s not found\n", GMT_program, infile);
