@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdimage.c,v 1.5 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: grdimage.c,v 1.5.4.10 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
  * Ver:		3.3.2	Added -S as in grdproject
  * Ver:		3.3.3	Added -T[s] for non-interpolated tiling
  * Ver:		3.3.6	-T needed polygon clipping and wrapping (like psxy)
- * Ver:		3.4
+ * Ver:		3.4.3
  */
  
 #include "gmt.h"
@@ -47,10 +47,10 @@ void GMT_set_proj_limits (struct GRD_HEADER *r, struct GRD_HEADER *g);
 main (int argc, char **argv)
 {
 	int i, j, k, kk, rgb[3], nm, nm2, byte, off, nx_f, ny_f, grid_type, polarity;
-	int nx, ny, dpi = 0, nx_proj = 0, ny_proj = 0, node, f_rgb[3], tiling = 0;
+	int nx, ny, dpi = 0, nx_proj = 0, ny_proj = 0, node, f_rgb[3], tiling = 0, index;
 	
-	BOOLEAN error = FALSE, intens = FALSE, monochrome = FALSE;
-	BOOLEAN mapped = FALSE, set_dpi = FALSE, subset = FALSE, transparent = FALSE;
+	BOOLEAN error = FALSE, intens = FALSE, monochrome = FALSE, need_to_project;
+	BOOLEAN set_dpi = FALSE, subset = FALSE, transparent = FALSE;
 	
 	double  dx, dy, x_side, y_side, x0 = 0.0, y0 = 0.0, max_radius = 0.0;
 	double west, east, south, north, data_west, data_east, data_south, data_north;
@@ -222,7 +222,16 @@ main (int argc, char **argv)
 
 	/* Determine the wesn to be used to read the grdfile */
 
-	GMT_grd_setregion (&g_head, &data_west, &data_east, &data_south, &data_north);
+	if (GMT_grd_setregion (&g_head, &data_west, &data_east, &data_south, &data_north)) {	/* No grid to plot; just do empty map and exit */
+		ps_plotinit (CNULL, gmtdefs.overlay, gmtdefs.page_orientation, gmtdefs.x_origin, gmtdefs.y_origin,
+			gmtdefs.global_x_scale, gmtdefs.global_y_scale, gmtdefs.n_copies,
+			gmtdefs.dpi, GMT_INCH , gmtdefs.paper_width, gmtdefs.page_rgb, GMT_epsinfo (argv[0]));
+		GMT_echo_command (argc, argv);
+		if (gmtdefs.unix_time) GMT_timestamp (argc, argv);
+		GMT_map_basemap ();
+		ps_plotend (gmtdefs.last_page);
+		GMT_end (argc, argv);
+	}
 
 	nx_f = g_head.nx;
 	ny_f = g_head.ny;
@@ -265,11 +274,9 @@ main (int argc, char **argv)
 	}
 	
 	GMT_set_proj_limits (&r_head, &g_head);
+	need_to_project = (project_info.projection > 5 || (project_info.projection == LINEAR && (project_info.xyz_projection[0] + project_info.xyz_projection[1]) > 0));
 
-	/* if (dpi > 0 || MAPPING) { */
-	if (!tiling && (dpi > 0 || project_info.projection > 5)) {	/* Need to resample the grd file */
-		
-		mapped = TRUE;
+	if (!tiling && (dpi > 0 || need_to_project)) {	/* Need to resample the grd file */
 		
 		if (gmtdefs.verbose) fprintf (stderr, "%s: project grdfiles\n", GMT_program);
 	
@@ -300,6 +307,7 @@ main (int argc, char **argv)
 			GMT_free ((void *)tmp2);
 		}
 		nm = nm2;
+		project_info.xyz_pos[0] = project_info.xyz_pos[1] = 1;	/* Since we have applied the projection we do no longer have 'negative' axes */
 	}
 	else {	/* Simply copy g_head info to r_head */
 		map = tmp1;
@@ -347,7 +355,7 @@ main (int argc, char **argv)
 				if (GMT_is_fnan (map[node]) && tiling == 2) continue;
 				index = GMT_get_rgb24 (map[node], rgb);
 				if (GMT_cpt_skip) continue;	/* Skip this z-slice */
-				if (intens) GMT_illuminate (intensity[node], rgb);
+				if (intens && index != -1) GMT_illuminate (intensity[node], rgb);
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = YIQ (rgb);
 				
 				np = GMT_graticule_path (&xx, &yy, 1, grd_x[i] - dx2, grd_x[i] + dx2, y_bot, y_top);
@@ -422,8 +430,8 @@ main (int argc, char **argv)
 		kk = r_head.nx * (project_info.xyz_pos[1] ? j : r_head.ny - j - 1);
 		for (i = 0; i < r_head.nx; i++) {	/* Compute rgb for each pixel */
 			node = kk + (project_info.xyz_pos[0] ? i : r_head.nx - i - 1);
-			GMT_get_rgb24 (map[node], rgb);
-			if (intens) GMT_illuminate (intensity[node], rgb);
+			index = GMT_get_rgb24 (map[node], rgb);
+			if (intens && index != -1) GMT_illuminate (intensity[node], rgb);
 
 			if (GMT_gray)	/* Color table only has grays, pick r */
 				bitimage_8[byte++] = (unsigned char) rgb[0];
