@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdinfo.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: grdinfo.c,v 1.2.4.8 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
  * 		3.3.2	Added -D option
  * 		3.3.3	Added -F option via M. Odegard
  * 		3.3.5	12-JUL-2000
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -43,7 +43,7 @@ main (int argc, char **argv)
 	BOOLEAN world_form = FALSE, geographic = FALSE, columns = FALSE;
 	
 	double x_min, y_min, z_min, x_max, y_max, z_max;
-	double mean, median, sum2, stdev, scale, rms, x;
+	double mean, median, sum2, stdev, scale, rms, x, half;
 	
 	char file[BUFSIZ], format[BUFSIZ];
 	
@@ -151,6 +151,8 @@ main (int argc, char **argv)
 		
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Processing file %s\n", GMT_program, file);
 
+		half = (grd.node_offset) ? 0.5 : 0.0;
+		
 		if (grd.z_min == grd.z_max && GMT_grd_i_format) quick = FALSE, find_max = TRUE;
 		
 		if (!quick) {	/* Must determine the location of global min and max values */
@@ -184,10 +186,10 @@ main (int argc, char **argv)
 				}
 			}
 		
-			x_min = grd.x_min + (i_min % grd.nx) * grd.x_inc;
-			y_min = grd.y_max - (i_min / grd.nx) * grd.y_inc;
-			x_max = grd.x_min + (i_max % grd.nx) * grd.x_inc;
-			y_max = grd.y_max - (i_max / grd.nx) * grd.y_inc;
+			x_min = grd.x_min + ((i_min % grd.nx) + half) * grd.x_inc;
+			y_min = grd.y_max - ((i_min / grd.nx) + half) * grd.y_inc;
+			x_max = grd.x_min + ((i_max % grd.nx) + half) * grd.x_inc;
+			y_max = grd.y_max - ((i_max / grd.nx) + half) * grd.y_inc;
 		}
 
 		if (l1) {	/* Calculate the median and L1 scale */
@@ -208,18 +210,18 @@ main (int argc, char **argv)
 		/* OK, time to report results */
 
 		if (columns) {
-			sprintf (format, "%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%d\t%d\0", file, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, grd.nx, grd.ny);
+			sprintf (format, "%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%d\t%d", file, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, grd.nx, grd.ny);
 			fprintf (GMT_stdout, format, grd.x_min, grd.x_max, grd.y_min, grd.y_max, grd.z_min, grd.z_max, grd.x_inc, grd.y_inc);
 			if (find_max) {
-				sprintf (format, "\t%s\t%s\t%s\t%s\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+				sprintf (format, "\t%s\t%s\t%s\t%s", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 				fprintf (GMT_stdout, format, x_min, y_min, x_max, y_max);
 			}
 			if (l1) {
-				sprintf (format, "\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+				sprintf (format, "\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format);
 				fprintf (GMT_stdout, format, median, scale);
 			}
 			if (l2) {
-				sprintf (format, "\t%s\t%s\t%s\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+				sprintf (format, "\t%s\t%s\t%s", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 				fprintf (GMT_stdout, format, mean, stdev, rms);
 			}
 			if (find_max) fprintf (GMT_stdout, "\t%d", n_nan);
@@ -236,11 +238,11 @@ main (int argc, char **argv)
 				GMT_format_ddmmss (grd.x_min, item1);
 				GMT_format_ddmmss (grd.x_max, item2);
 				GMT_format_ddmmss (grd.x_inc, item3);
-				fprintf (GMT_stdout, "%s: x_min: %s x_max: %s x_inc: %s units: %s nx: %d\n\0", file, item1, item2, item3, grd.x_units, grd.nx);
+				fprintf (GMT_stdout, "%s: x_min: %s x_max: %s x_inc: %s units: %s nx: %d\n", file, item1, item2, item3, grd.x_units, grd.nx);
 				GMT_format_ddmmss (grd.y_min, item1);
 				GMT_format_ddmmss (grd.y_max, item2);
 				GMT_format_ddmmss (grd.y_inc, item3);
-				fprintf (GMT_stdout, "%s: y_min: %s y_max: %s y_inc: %s units: %s ny: %d\n\0", file, item1, item2, item3, grd.y_units, grd.ny);
+				fprintf (GMT_stdout, "%s: y_min: %s y_max: %s y_inc: %s units: %s ny: %d\n", file, item1, item2, item3, grd.y_units, grd.ny);
 			}
 			else if (world_form) {
 				if ((fabs (grd.x_min) < 500.0) && (fabs (grd.x_max) < 500.0) && (fabs (grd.y_min) < 500.0) && (fabs (grd.y_max) < 500.0)) {
@@ -269,16 +271,16 @@ main (int argc, char **argv)
 				}
 			}
 			else {
-				sprintf (format, "%s: x_min: %s x_max: %s x_inc: %s units: %s nx: %d\n\0", file, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, grd.x_units, grd.nx);
+				sprintf (format, "%s: x_min: %s x_max: %s x_inc: %s units: %s nx: %d\n", file, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, grd.x_units, grd.nx);
 				fprintf (GMT_stdout, format, grd.x_min, grd.x_max, grd.x_inc);
-				sprintf (format, "%s: y_min: %s y_max: %s y_inc: %s units: %s ny: %d\n\0", file, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, grd.y_units, grd.ny);
+				sprintf (format, "%s: y_min: %s y_max: %s y_inc: %s units: %s ny: %d\n", file, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, grd.y_units, grd.ny);
 				fprintf (GMT_stdout, format, grd.y_min, grd.y_max, grd.y_inc);
 			}
 			
 			if (find_max) {
 				if (z_min == -DBL_MAX) z_min = GMT_d_NaN;
 				if (z_max == +DBL_MAX) z_max = GMT_d_NaN;
-				sprintf (format, "%s: z_min: %s at x = %s y = %s z_max: %s at x = %s y = %s units: %s\n\0", file, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, grd.z_units);
+				sprintf (format, "%s: z_min: %s at x = %s y = %s z_max: %s at x = %s y = %s units: %s\n", file, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, grd.z_units);
 				fprintf (GMT_stdout, format, z_min, x_min, y_min, z_max, x_max, y_max);
 			}
 			else if (world_form) {
@@ -287,19 +289,19 @@ main (int argc, char **argv)
 				fprintf (GMT_stdout, "%s: units: %s\n", file, grd.z_units);
 			}
 			else {
-				sprintf (format, "%s: z_min: %s z_max: %s units: %s\n\0", file, gmtdefs.d_format, gmtdefs.d_format, grd.z_units);
+				sprintf (format, "%s: z_min: %s z_max: %s units: %s\n", file, gmtdefs.d_format, gmtdefs.d_format, grd.z_units);
 				fprintf (GMT_stdout, format, grd.z_min, grd.z_max);
 			}
 
-			sprintf (format, "%s: scale_factor: %s add_offset: %s\n\0", file, gmtdefs.d_format, gmtdefs.d_format);
+			sprintf (format, "%s: scale_factor: %s add_offset: %s\n", file, gmtdefs.d_format, gmtdefs.d_format);
 			fprintf (GMT_stdout, format, grd.z_scale_factor, grd.z_add_offset);
 			if (n_nan) fprintf (GMT_stdout, "%s: %d nodes set to NaN\n", file, n_nan);
 			if (l1) {
-				sprintf (format, "%s: median: %s scale: %s\n\0", file, gmtdefs.d_format, gmtdefs.d_format);
+				sprintf (format, "%s: median: %s scale: %s\n", file, gmtdefs.d_format, gmtdefs.d_format);
 				fprintf (GMT_stdout, format, median, scale);
 			}
 			if (l2) {
-				sprintf (format, "%s: mean: %s stdev: %s rms: %s\n\0", file, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+				sprintf (format, "%s: mean: %s stdev: %s rms: %s\n", file, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 				fprintf (GMT_stdout, format, mean, stdev, rms);
 			}
 		}
@@ -341,7 +343,7 @@ void GMT_format_ddmmss (double val, char *format)
 	}
 
 	if (frac_sec > SMALL)	/* Must preserve second fraction */
-		sprintf (format, "%d:%2.2d:%2.2d.%3.3d\0", sign * ival, minutes, seconds, irint (1000.0 * frac_sec));
+		sprintf (format, "%d:%2.2d:%2.2d.%3.3d", sign * ival, minutes, seconds, irint (1000.0 * frac_sec));
 	else
-		sprintf (format, "%d:%2.2d:%2.2d\0", sign * ival, minutes, seconds);
+		sprintf (format, "%d:%2.2d:%2.2d", sign * ival, minutes, seconds);
 }
