@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdlandmask.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grdlandmask.c,v 1.3.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
  * Modified:	24-JUN-1998, for GMT 3.1
  *		18-AUG-1999, for GMT 3.3.2
  *		13-JUL-2000, for GMT 3.3.5
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -190,7 +190,7 @@ main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 	
-	sprintf (line, "%s\n\0", gmtdefs.d_format);
+	sprintf (line, "%s\n", gmtdefs.d_format);
 	if (gmtdefs.verbose && dry_wet_only) {
 		fprintf (stderr, "%s: Nodes in water will be set to ", GMT_program);
 		(GMT_is_fnan (out_edge_in[0])) ? fprintf (stderr, "NaN\n") : fprintf (stderr, line, out_edge_in[0]);
