@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdmask.c,v 1.3 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: grdmask.c,v 1.3.4.8 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,8 @@
  *				and for -S check if points are inside -R.
  *				Also added -L for geographic data
  * 		PW: 13-JUL-2000, 3.3.5
- * Version:	3.4
+ *		PW: 20-AUG-2002, Added -A and do fix_up path as in psxy
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -42,11 +43,11 @@ main (int argc, char **argv)
 	int	i, j, k, ij, nm, n_path, side, fno, n_files = 0, n_alloc = GMT_CHUNK, n_args;
 	int	one_or_zero, di, dj, i0, j0, n_fields, n_read, n_expected_fields, polar;
 	
-	BOOLEAN	error = FALSE, done, nofile = TRUE, pixel = FALSE;
-	BOOLEAN	do_coverage = FALSE, map_units = FALSE;
+	BOOLEAN	error = FALSE, done, nofile = TRUE, pixel = FALSE, draw_arc = TRUE, greenwich;
+	BOOLEAN	do_coverage = FALSE, map_units = FALSE, resample = FALSE;
 	
 	double	*x, *y, xx, yy, xmin, xmax, ymin, ymax, offset, dx, dy, r, ca, sa, lon_sum, dlon;
-	double xinc2, yinc2, distance, radius = 0.0, shrink, km_pr_deg, idx, idy, x0, y0, *in;
+	double xinc2, yinc2, distance, radius = 0.0, shrink, km_pr_deg, idx, idy, x0, y0, *in, step = 1.0;
 
 	float out_edge_in[3];
 	
@@ -84,6 +85,12 @@ main (int argc, char **argv)
 				case 'b':
 					error += GMT_io_selection (&argv[i][2]);
 					break;
+				case 'A':	/* Turn off draw_arc mode */
+					if (argv[i][2])
+						step = atof (&argv[i][2]);	/* Undocumented test feature */
+					else
+						draw_arc = FALSE;
+					break;
 				case 'N':
 					strcpy (line, &argv[i][2]);
 					ptr = strtok (line, "/");
@@ -125,7 +132,7 @@ main (int argc, char **argv)
 	if (argc == 1 || GMT_quick) {
 		fprintf (stderr, "grdmask %s - Create mask grdfile from polygons or point coverage\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdmask [<xyfiles>] -G<mask_grd_file> -I<xinc[m|c]>[/<yinc>[m|c]]\n");
-		fprintf (stderr, "\t-R<west/east/south/north> [-F] [-H[<nrec>]] [-L] [-N<out>/<edge>/<in>] [-M[<flag>]] [-S<radius>[k] [-V] [-:] [-bi[s][<n>]]\n\n");
+		fprintf (stderr, "\t-R<west/east/south/north> [-A] [-F] [-H[<nrec>]] [-L] [-N<out>/<edge>/<in>] [-M[<flag>]] [-S<radius>[k] [-V] [-:] [-bi[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -135,6 +142,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "\t   Default is yinc = xinc.  Append an m [or c] to indicate minutes [or seconds].\n");
 		GMT_explain_option ('R');
 		fprintf (stderr, "\n\tOPTIONS:\n");
+		fprintf (stderr, "\t-A Suppress connecting points using great circle arcs for geographic data\n");
 		fprintf (stderr, "\t-F Force pixel registration for output grid [Default is gridline orientation]\n");
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-L means that x is longitude, i.e. assumed to be periodic in 360\n");
@@ -208,7 +216,7 @@ main (int argc, char **argv)
 	x = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(double), GMT_program);
 	y = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(double), GMT_program);
 
-	sprintf (line, "%s\n\0", gmtdefs.d_format);
+	sprintf (line, "%s\n", gmtdefs.d_format);
 	if (gmtdefs.verbose) {
 		fprintf (stderr, "%s: Nodes completely outside the polygons will be set to ", GMT_program);
 		(GMT_is_fnan (out_edge_in[0])) ? fprintf (stderr, "NaN\n") : fprintf (stderr, line, out_edge_in[0]);
@@ -228,6 +236,9 @@ main (int argc, char **argv)
 		di = (int)ceil (radius * idx);
 		dj = (int)ceil (radius * idy);
 	}
+	resample = (draw_arc && GMT_geographic_in);
+	greenwich = (header.x_min <= 0.0 || header.x_max <= 0.0);
+	
 	/* Initialize all nodes to the 'outside' value */
 	
 	for (ij = 0; ij < nm; ij++) data[ij] = out_edge_in[0];
@@ -283,7 +294,7 @@ main (int argc, char **argv)
 				if (x[n_path] < xmin) xmin = x[n_path];
 				if (y[n_path] > ymax) ymax = y[n_path];
 				if (y[n_path] < ymin) ymin = y[n_path];
-				if (n_path > 0) {	/* Do longitude-difference check sum */
+				if (GMT_geographic_in && n_path > 0) {	/* Do longitude-difference check sum */
 					dlon = x[n_path] - x[n_path-1];
 					if (fabs (dlon) > 180.0) dlon = copysign (360.0 - fabs (dlon), -dlon);
 					lon_sum += dlon;
@@ -332,15 +343,20 @@ main (int argc, char **argv)
 				}
 			}
 			else {	/* assign 'inside' to nodes if they are inside given polygon */
-				if (x[n_path-1] != x[0] || y[n_path-1] != y[0]) {
+				if (x[n_path-1] != x[0] || y[n_path-1] != y[0]) {	/* Explicitly close the polygon */
 					x[n_path] = x[0];
 					y[n_path] = y[0];
 					dlon = x[n_path] - x[n_path-1];
 					n_path++;
-					if (fabs (dlon) > 180.0) dlon = copysign (360.0 - fabs (dlon), -dlon);
-					lon_sum += dlon;
+					if (GMT_geographic_in) {
+						if (fabs (dlon) > 180.0) dlon = copysign (360.0 - fabs (dlon), -dlon);
+						lon_sum += dlon;
+					}
 				}
-				if (fabs (fabs (lon_sum) - 360.0) < GMT_CONV_LIMIT) {	/* Contains a pole, convert to polar x,y */
+				
+				if (resample) n_path = GMT_fix_up_path (&x, &y, n_path, greenwich, step);
+				
+				if (GMT_geographic_in && fabs (fabs (lon_sum) - 360.0) < GMT_CONV_LIMIT) {	/* Contains a pole, convert to polar x,y */
 					polar = (y[0] < 0.0) ? -1 : +1;	/* S or N pole */
 					for (j = 0; j < n_path; j++) {
 						r = 90.0 - fabs (y[j]);
