@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdmath_main.c,v 1.5 2001/04/11 19:58:09 pwessel Exp $
+ *	$Id: grdmath_main.c,v 1.5.4.10 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -35,6 +35,8 @@
  *		20-AUG-2000 PW: Added FDIST, TDIST, CHI2DIST
  *		23-AUG-2000 PW: Added LOWER and UPPER
  * Version:	3.4
+ *		3.4.1	EXTREMA did not consider edges
+ *		3.4.3
  *
  */
  
@@ -58,7 +60,7 @@ PFV call_operator[N_OPERATORS];
 
 int nm = 0, consumed_operands[N_OPERATORS], produced_operands[N_OPERATORS];
 
-struct GMT_HASH hashnode[HASH_SIZE];
+struct GMT_HASH localhashnode[HASH_SIZE];
 
 float *grd_x, *grd_y;
 
@@ -142,7 +144,7 @@ main (int argc, char **argv)
 			fprintf (stderr, "%s Warning: Your file %s may be confused with a %s operator!\n", GMT_program, special_arg[i], GMT_program);
 	}
 
-	GMT_hash_init (hashnode, operator, HASH_SIZE, N_OPERATORS);
+	GMT_hash_init (localhashnode, operator, HASH_SIZE, N_OPERATORS);
 
 	for (i = 0; i < STACK_SIZE; i++) {
 		constant[i] = FALSE;
@@ -623,8 +625,8 @@ void grd_CURV (float *stack[], BOOLEAN *constant, double *factor, int last)
 	z = (float *) (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
  
 	nx = header.nx;
-	cx = 0.5 / (header.x_inc * header.x_inc);
-	cy = 0.5 / (header.y_inc * header.y_inc);
+	cx = +0.5 / (header.x_inc * header.x_inc);
+	cy = -0.5 / (header.y_inc * header.y_inc);	/* Because the loop over j below goes from ymax to ymin we compensate with a minus sign here */
 
 	/* First left/right */
 
@@ -696,7 +698,7 @@ void grd_D2DY2 (float *stack[], BOOLEAN *constant, double *factor, int last)
 		return;
 	}
 
-	c = 1.0 / (header.y_inc * header.y_inc);
+	c = -1.0 / (header.y_inc * header.y_inc);	/* Because the loop over j below goes from ymax to ymin we compensate with a minus sign here */
 	nx = header.nx;
 	for (i = 0; i < header.nx; i++) {
 		k = i;
@@ -762,7 +764,7 @@ void grd_DDY (float *stack[], BOOLEAN *constant, double *factor, int last)
 		return;
 	}
 
-	c = 0.5 / header.y_inc;
+	c = -0.5 / header.y_inc;	/* Because the loop over j below goes from ymax to ymin we compensate with a minus sign here */
 	nx = header.nx;
 	for (i = 0; i < header.nx; i++) {
 		k = i;
@@ -800,8 +802,10 @@ void grd_DIV (float *stack[], BOOLEAN *constant, double *factor, int last)
 		exit (EXIT_FAILURE);
 	}
 	if (constant[last]) {	/* Turn divide into multiply */
+		a = factor[last];	/* Save original factor */
 		factor[last] = 1.0 / factor[last];
 		grd_MUL (stack, constant, factor, last);
+		factor[last] = a;	/* Restore factor */
 		return;
 	}
 	
@@ -894,8 +898,8 @@ void grd_EXP (float *stack[], BOOLEAN *constant, double *factor, int last)
 
 void grd_EXTREMA (float *stack[], BOOLEAN *constant, double *factor, int last)
 {
-	int i, j, k, nx, x_status, y_status, xy_status[11];
-	float *z;
+	int i, j, k, nx, nx2, ny1, nx1, x_status, y_status, xy_status[11];
+	float *z, *z_left, *z_right, *z_top, *z_bot, left, right, top, bot;
 
 	/* Find local extrema in grid */
 
@@ -904,38 +908,85 @@ void grd_EXTREMA (float *stack[], BOOLEAN *constant, double *factor, int last)
 		memset ((void *)stack[last], 0, (size_t)(nm * sizeof (float)));
 		return;
 	}
+	if (header.nx < 2 || header.ny < 2) {	/* Cannot deal with profiles camouflaging as grids */
+		if (gmtdefs.verbose) fprintf (stderr, "%s: Warning, operand EXTREMA requires both nx,ny to be >= 2!\n", GMT_program);
+		memset ((void *)stack[last], 0, (size_t)(nm * sizeof (float)));
+		return;
+	}
 	
-	z = (float *) (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
+	z = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
+	z_left  = (float *) GMT_memory (VNULL, (size_t)header.ny, sizeof (float), GMT_program);
+	z_right = (float *) GMT_memory (VNULL, (size_t)header.ny, sizeof (float), GMT_program);
+	z_top   = (float *) GMT_memory (VNULL, (size_t)header.nx, sizeof (float), GMT_program);
+	z_bot   = (float *) GMT_memory (VNULL, (size_t)header.nx, sizeof (float), GMT_program);
  
- 	memset ((void *)xy_status, 0, (size_t)(11 * sizeof (int)));
+	memset ((void *)xy_status, 0, (size_t)(11 * sizeof (int)));
 	xy_status[5] = -2;	xy_status[6] = +1;	xy_status[9] = -1;	xy_status[10] = +2;
 	
 	nx = header.nx;
+	nx1 = nx - 1;
+	ny1 = header.ny - 1;
+	nx2 = nm - nx;
+	k = nx2 - nx;
+ 	for (i = 0; i < header.nx; i++) {	/* Get extra rows using Natural Boundary Cconditions */
+		z_top[i] = (float)(2.0 * stack[last][i] - stack[last][nx+i]);
+		z_bot[i] = (float)(2.0 * stack[last][nx2+i] - stack[last][k+i]);
+	}
+ 	for (j = 0; j < header.ny; j++) {	/* Get extra columns using Natural Boundary Cconditions */
+		k = j * nx;
+		z_left[j]  = (float)(2.0 * stack[last][k] - stack[last][k+1]);
+		z_right[j] = (float)(2.0 * stack[last][k+nx-1] - stack[last][k+nx-2]);
+	}
+	
+ 	/* Search the entire grid, using boundary points when needed */
 
-	/* Search the inside of the grid only*/
-
-	for (j = 1, k = nx; j < header.ny-1; j++) {
-		k++;	/* k is middle (current) node */
-		for (i = 1; i < header.nx-1; i++, k++) {
+	for (j = k = 0; j < header.ny; j++) {
+		/* k is middle (current) node */
+		for (i = 0; i < header.nx; i++, k++) {
+		
+			if (i == 0) {		/* Along left edge */
+				left = z_left[j];
+				right = stack[last][k+1];
+			}
+			else if (i == nx1) {	/* Along right edge */
+				right = z_right[j];
+				left = stack[last][k-1];
+			}
+			else {			/* In the middle somewhere */
+				left = stack[last][k-1];
+				right = stack[last][k+1];
+			}
+			if (j == 0) {		/* Along top edge */
+				top = z_top[i];
+				bot = stack[last][k+nx];
+			}
+			else if (j == ny1) {	/* Along bottom edge */
+				top = stack[last][k-nx];
+				bot = z_bot[i];
+			}
+			else {			/* In the middle somewhere */
+				top = stack[last][k-nx];
+				bot = stack[last][k+nx];
+			}
 			/* Examine x-slice for local maxima */
-			if (stack[last][k] >= stack[last][k-1] && stack[last][k] > stack[last][k+1])
+			if (stack[last][k] >= left && stack[last][k] > right)
 				x_status = 2;
-			else if (stack[last][k] > stack[last][k-1] && stack[last][k] >= stack[last][k+1])
+			else if (stack[last][k] > left && stack[last][k] >= right)
 				x_status = 2;
-			else if (stack[last][k] <= stack[last][k-1] && stack[last][k] < stack[last][k+1])
+			else if (stack[last][k] <= left && stack[last][k] < right)
 				x_status = 1;
-			else if (stack[last][k] < stack[last][k-1] && stack[last][k] <= stack[last][k+1])
+			else if (stack[last][k] < left && stack[last][k] <= right)
 				x_status = 1;
 			else
 				x_status = 0;
 			/* Examine y-slice for local maxima */
-			if (stack[last][k] >= stack[last][k-nx] && stack[last][k] > stack[last][k+nx])
+			if (stack[last][k] >= top && stack[last][k] > bot)
 				y_status = 8;
-			else if (stack[last][k] > stack[last][k-nx] && stack[last][k] >= stack[last][k+nx])
+			else if (stack[last][k] > top && stack[last][k] >= bot)
 				y_status = 8;
-			else if (stack[last][k] <= stack[last][k-nx] && stack[last][k] < stack[last][k+nx])
+			else if (stack[last][k] <= top && stack[last][k] < bot)
 				y_status = 4;
-			else if (stack[last][k] < stack[last][k-nx] && stack[last][k] <= stack[last][k+nx])
+			else if (stack[last][k] < top && stack[last][k] <= bot)
 				y_status = 4;
 			else
 				y_status = 0;
@@ -950,11 +1001,14 @@ void grd_EXTREMA (float *stack[], BOOLEAN *constant, double *factor, int last)
 			
 			z[k] = (float)xy_status[x_status|y_status]; 
 		}
-		k++;
 	}
 
 	memcpy ((void *)stack[last], (void *)z, (size_t)(nm * sizeof (float)));
 	GMT_free ((void *)z);
+	GMT_free ((void *)z_left);
+	GMT_free ((void *)z_right);
+	GMT_free ((void *)z_top);
+	GMT_free ((void *)z_bot);
 }
 
 void grd_FDIST (float *stack[], BOOLEAN *constant, double *factor, int last)
@@ -1292,7 +1346,7 @@ void grd_LMSSCL (float *stack[], BOOLEAN *constant, double *factor, int last)
 	/* Sort will put any NaNs to the end - we then count to find the real data */
 	
 	qsort ((void *)stack[last], (size_t)nm, sizeof (float), GMT_comp_float_asc);
-	for (i = nm-1; GMT_is_fnan (stack[last][i]) && i > 0; i--);
+	for (i = nm; GMT_is_fnan (stack[last][i-1]) && i > 1; i--);
 	if (i) {
 		GMT_mode_f (stack[last], i, i/2, 0, &mode);
 		GMT_getmad_f (stack[last], i, mode, &lmsscl);
@@ -1348,7 +1402,7 @@ void grd_MAD (float *stack[], BOOLEAN *constant, double *factor, int last)
 	/* Sort will put any NaNs to the end - we then count to find the real data */
 	
 	qsort ((void *)stack[last], (size_t)nm, sizeof (float), GMT_comp_float_asc);
-	for (i = nm-1; GMT_is_fnan (stack[last][i]) && i > 0; i--);
+	for (i = nm; GMT_is_fnan (stack[last][i-1]) && i > 1; i--);
 	if (i) {
 		med = (i%2) ? stack[last][i/2] : (float)(0.5 * (stack[last][(i-1)/2] + stack[last][i/2]));
 		GMT_getmad_f (stack[last], i, med, &mad);
@@ -1403,7 +1457,7 @@ void grd_MED (float *stack[], BOOLEAN *constant, double *factor, int last)
 	}
 
 	qsort ((void *)stack[last], (size_t)nm, sizeof (float), GMT_comp_float_asc);
-	for (i = nm-1; GMT_is_fnan (stack[last][i]) && i > 0; i--);
+	for (i = nm; GMT_is_fnan (stack[last][i-1]) && i > 1; i--);
 	if (i)
 		med = (i%2) ? stack[last][i/2] : (float)(0.5 * (stack[last][(i-1)/2] + stack[last][i/2]));
 	else
@@ -1436,7 +1490,7 @@ void grd_MODE (float *stack[], BOOLEAN *constant, double *factor, int last)
 	}
 	
 	qsort ((void *)stack[last], (size_t)nm, sizeof (float), GMT_comp_float_asc);
-	for (i = nm-1; GMT_is_fnan (stack[last][i]) && i > 0; i--);
+	for (i = nm; GMT_is_fnan (stack[last][i-1]) && i > 1; i--);
 	if (i)
 		GMT_mode_f (stack[last], i, i/2, 0, &mode);
 	else
@@ -1999,7 +2053,7 @@ char *choice; {
 	
 	/* Returns -1 if not a registered operator */
 
-	op = GMT_hash_lookup (choice, hashnode, HASH_SIZE);
+	op = GMT_hash_lookup (choice, localhashnode, HASH_SIZE);
 
 	if (op < 0 && strlen (choice) == 1) {	/* Check for old-style operators */
 	
