@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdpaste.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: grdpaste.c,v 1.2.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
  * Updated to v2.0 20-May-1991 Paul Wessel
  * Updated to v3.1 23-May-1998 Paul Wessel
  * 3.3.5 23-JUN-2000 Paul Wessel
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
  
@@ -203,7 +203,7 @@ main (int argc, char **argv)
 
 	/* Now we can do it  */
 
-	sprintf (format, "%%s: \t%s\t%s\t%s\t%s\t%s\t%s\t%%d\t%%d\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format, "%%s: \t%s\t%s\t%s\t%s\t%s\t%s\t%%d\t%%d\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 	if (gmtdefs.verbose) {
 		fprintf (stderr, "File spec:\tW E S N dx dy nx ny:\n");
 		fprintf (stderr, format, grd_a, ha.x_min, ha.x_max, ha.y_min, ha.y_max, ha.x_inc, ha.y_inc, ha.nx, ha.ny);
