@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdproject.c,v 1.4 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grdproject.c,v 1.4.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
  *
  * Author:	Paul Wessel
  * Date:	15-JUL-2000
- * Ver:		3.4
+ * Ver:		3.4.3
  *
  */
 
@@ -39,7 +39,7 @@ main (int argc, char **argv)
 	BOOLEAN d_set = FALSE, e_set = FALSE, m_set = FALSE, map_center = FALSE, offset, toggle_offset = FALSE;
 	
 	double w, e, s, n, x_inc = 0.0, y_inc = 0.0, max_radius = 0.0, one_or_zero;
-	double xmin, xmax, ymin, ymax, inch_to_unit, unit_to_inch, utm_correct, fwd_scale, inv_scale;
+	double xmin, xmax, ymin, ymax, inch_to_unit, unit_to_inch, fwd_scale, inv_scale;
 	
 	char *infile, *outfile, format[BUFSIZ], unit_name[80], scale_unit_name[80];
 	
@@ -187,19 +187,17 @@ main (int argc, char **argv)
 	GMT_init_scales (unit, &fwd_scale, &inv_scale, &inch_to_unit, &unit_to_inch, unit_name);
 
 	GMT_map_setup (w, e, s, n);
-	
-	utm_correct = (project_info.projection == UTM && !project_info.north_pole) ? FALSE_NORTHING : 0.0;
 
 	xmin = (map_center) ? project_info.xmin - project_info.x0 : project_info.xmin;
 	xmax = (map_center) ? project_info.xmax - project_info.x0 : project_info.xmax;
 	ymin = (map_center) ? project_info.ymin - project_info.y0 : project_info.ymin;
-	ymax = (map_center) ? project_info.ymax - project_info.y0 + utm_correct : project_info.ymax;
+	ymax = (map_center) ? project_info.ymax - project_info.y0 : project_info.ymax;
 	if (one_to_one) {	/* Convert to chosen units */
 		strncpy (unit_name, scale_unit_name, 80);
 		xmin /= project_info.x_scale;
 		xmax /= project_info.x_scale;
-		ymin = (ymin / project_info.y_scale) + utm_correct;
-		ymax = (ymax / project_info.y_scale) + utm_correct;
+		ymin /= project_info.y_scale;
+		ymax /= project_info.y_scale;
 		if (unit) {	/* Change the 1:1 unit used */
 			xmin *= fwd_scale;
 			xmax *= fwd_scale;
@@ -217,7 +215,7 @@ main (int argc, char **argv)
 	GMT_grd_init (&r_head, argc, argv, FALSE);
 	GMT_grd_init (&g_head, argc, argv, FALSE);
 
-	sprintf (format, "(%s/%s/%s/%s)\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format, "(%s/%s/%s/%s)", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 
 	if (inverse) {	/* Transforming from rectangular projection to geographical */
 	
@@ -263,8 +261,8 @@ main (int argc, char **argv)
 			}
 			r_head.x_min *= project_info.x_scale;
 			r_head.x_max *= project_info.x_scale;
-			r_head.y_min = (r_head.y_min - utm_correct) * project_info.y_scale;
-			r_head.y_max = (r_head.y_max - utm_correct) * project_info.y_scale;
+			r_head.y_min *= project_info.y_scale;
+			r_head.y_max *= project_info.y_scale;
 			max_radius *= project_info.x_scale;
 		}
 		else if (gmtdefs.measure_unit != GMT_INCH) {	/* Convert from inch to whatever */
@@ -357,8 +355,8 @@ main (int argc, char **argv)
 		if (one_to_one) {	/* Convert to 1:1 scale */
 			r_head.x_min /= project_info.x_scale;
 			r_head.x_max /= project_info.x_scale;
-			r_head.y_min = (r_head.y_min / project_info.y_scale) + utm_correct;
-			r_head.y_max = (r_head.y_max / project_info.y_scale) + utm_correct;
+			r_head.y_min /= project_info.y_scale;
+			r_head.y_max /= project_info.y_scale;
 			if (unit) {	/* Change the 1:1 unit used */
 				r_head.x_min *= fwd_scale;
 				r_head.x_max *= fwd_scale;
