@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdreformat.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: grdreformat.c,v 1.2.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  *
  * Author:	Paul Wessel
  * Date:	3-JAN-1991-2000
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -86,7 +86,7 @@ main (int argc, char **argv)
 		GMT_explain_option ('V');
 		
 		fprintf (stderr, "	The following formats are supported\n\n");
-		sprintf (line, "%s%cshare%cgmtformats.d\0", GMTHOME, DIR_DELIM, DIR_DELIM);
+		sprintf (line, "%s%cshare%cgmtformats.d", GMTHOME, DIR_DELIM, DIR_DELIM);
 		if ((fp = fopen (line, "r")) == NULL) {
 			fprintf (stderr, "%s: GMT ERROR: Cannot read file %s\n", GMT_program, line);
 			exit (EXIT_FAILURE);
