@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdsample.c,v 1.4 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grdsample.c,v 1.4.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
  * Date:	19-JUL-1989
  * Revised:	6-JAN-1990	PW: Updated to v.2.0
  * Revised:	16-JUN-1998	PW: Updated to v.3.1
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -125,6 +125,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "\t-Q do quick, bilinear interpolation [Default is bicubic]\n");
 		fprintf (stderr, "\t-R specifies a subregion [Default is old region]\n");
 		fprintf (stderr, "\t-T Toggles between grid registration and pixel registration\n");
+		fprintf (stderr, "\t   In this case, -N is ignored.\n");
 		GMT_explain_option ('V');
 		fprintf (stderr, "\t   One only of -N -I must be specified\n");
 		
@@ -223,7 +224,7 @@ main (int argc, char **argv)
 
 	b = (float *) GMT_memory (VNULL, (size_t)(grd_b.nx * grd_b.ny), sizeof(float), GMT_program);
 	
-	sprintf (format, "%%s: New grid (%s/%s/%s/%s) nx = %%d ny = %%d dx = %s dy = %s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format, "%%s: New grid (%s/%s/%s/%s) nx = %%d ny = %%d dx = %s dy = %s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 	if (gmtdefs.verbose) fprintf (stderr, format, GMT_program, grd_b.x_min, grd_b.x_max, grd_b.y_min, grd_b.y_max, grd_b.nx, grd_b.ny, grd_b.x_inc, grd_b.y_inc);
 	
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;	/* Leave room for 2 empty boundary rows/cols */
