@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdtrack.c,v 1.5 2001/04/04 00:59:32 pwessel Exp $
+ *	$Id: grdtrack.c,v 1.5.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -37,7 +37,7 @@
  *		4-AUG-1993	PW: Added -Q
  *		14-AUG-1998	PW: GMT 3.1
  *  Modified:	10 Jul 2000 3.3.5  by PW to allow plain -L to indicate geographic coordinates
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -127,7 +127,7 @@ main (int argc, char **argv)
 	if (argc == 1 || GMT_quick) {
 		fprintf (stderr,"grdtrack %s - Sampling of a 2-D gridded netCDF grdfile along 1-D trackline\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdtrack <xyfile> -G<grdfile> [-H[<nrec>]] [-L[<flag>]] [-M[<flag>]] [-Q]\n");
-		fprintf (stderr, "[-Rw/s/e/n[r]] [-S] [-V] [-Z] [-:] [-bi[s][<n>]] [-bo[s]]\n");
+		fprintf (stderr, "[-Rw/s/e/n[r]] [-S] [-V] [-Z] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -227,7 +227,7 @@ main (int argc, char **argv)
 	
 	GMT_boundcond_set (&grd, &edgeinfo, GMT_pad, f);
 	
-	sprintf (format1, "%s\t%s\t%%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format1, "%s\t%s\t%%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 	
 	if (gmtdefs.io_header) {	/* First echo headers, if any */
 		for (i = 0; i < gmtdefs.n_header_recs - 1; i++) {
