@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdtrend.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grdtrend.c,v 1.3.4.8 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -48,12 +48,12 @@ Median absolute deviation (MAD: Huber, 1982).  The
 
 Author:		W. H. F. Smith
 Date:		21 May, 1991.
-Version:	3.4
 Calls:		uses the QR solution of the Normal
 		equations furnished by Wm. Menke's
 		C routine "gauss".  We gratefully
 		acknowledge this contribution.
 Revised:	12-JUN-1998 PW, for GMT 3.1
+Version:	3.4.3
 
 Remarks:
 
@@ -250,7 +250,8 @@ main(int argc, char **argv)
 
 /* If a weight array is needed, get one:  */
 
-	if (weighted = (robust || w_filename) ) {
+	weighted = (robust || w_filename);
+	if (weighted) {
 		weight = (float *) GMT_memory (VNULL, (size_t)nxy, sizeof (float), GMT_program);
 		if (!access (w_filename, R_OK)) {	/* We have weights on input  */
 			GMT_grd_init (&head_w, argc, argv, FALSE);
@@ -302,7 +303,7 @@ main(int argc, char **argv)
 		if (robust) {
 			compute_chisq(resid, weight, nxy, &chisq, scale);
 			iterations = 1;
-			sprintf(format, "%%s Robust iteration %%d:  Old Chi Squared:  %s  New Chi Squared %s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+			sprintf(format, "%%s Robust iteration %%d:  Old Chi Squared:  %s  New Chi Squared %s\n", gmtdefs.d_format, gmtdefs.d_format);
 			do {
 				old_chisq = chisq;
 				for(k = 0; k < n_model; k++) old[k] = gtd[k];
@@ -341,7 +342,7 @@ main(int argc, char **argv)
 		strcpy (head_d.title, "trend residuals");
 		GMT_write_grd (d_filename, &head_d, resid, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
 	}
-	if (w_filename) {
+	if (w_filename && robust) {
 		strcpy (head_d.title, "trend weights");
 		GMT_write_grd (d_filename, &head_d, weight, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
 	}
@@ -541,18 +542,18 @@ void	write_model_parameters(double *gtd, int n_model)
 	int	i;
 	char	pbasis[10][16];
 
-	sprintf(pbasis[0], "Mean\0");
-	sprintf(pbasis[1], "X\0");
-	sprintf(pbasis[2], "Y\0");
-	sprintf(pbasis[3], "X*Y\0");
-	sprintf(pbasis[4], "P2(x)\0");
-	sprintf(pbasis[5], "P2(y)\0");
-	sprintf(pbasis[6], "P3(x)\0");
-	sprintf(pbasis[7], "P2(x)*P1(y)\0");
-	sprintf(pbasis[8], "P1(x)*P2(y)\0");
-	sprintf(pbasis[9], "P3(y)\0");
+	sprintf(pbasis[0], "Mean");
+	sprintf(pbasis[1], "X");
+	sprintf(pbasis[2], "Y");
+	sprintf(pbasis[3], "X*Y");
+	sprintf(pbasis[4], "P2(x)");
+	sprintf(pbasis[5], "P2(y)");
+	sprintf(pbasis[6], "P3(x)");
+	sprintf(pbasis[7], "P2(x)*P1(y)");
+	sprintf(pbasis[8], "P1(x)*P2(y)");
+	sprintf(pbasis[9], "P3(y)");
 
-	sprintf(format, "Coefficient fit to %%s:  %s\n\0", gmtdefs.d_format);
+	sprintf(format, "Coefficient fit to %%s:  %s\n", gmtdefs.d_format);
 	for(i = 0; i < n_model; i++) fprintf (stderr, format, pbasis[i], gtd[i]);
 
 	return;
