@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdvector.c,v 1.4 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grdvector.c,v 1.4.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
    Author:	Paul Wessel
    Date:	12-JUN-1995
    Revised:	15-FEB-2000
-   Version:	3.4
+   Version:	3.4.3
  
  */
 
@@ -202,7 +202,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "\t-S sets scale for vector length in data units per %s [1]\n", GMT_unit_names[gmtdefs.measure_unit]);
 		fprintf (stderr, "\t   Append c, i, m, or p to indicate cm, inch, m, or points as the distance unit.\n");
 		fprintf (stderr, "\t   Alternatively, prepend l to indicate a fixed length for all vectors.\n");
-		fprintf (stderr, "\t-T means aximuth should be convered to angles based on map projection\n");
+		fprintf (stderr, "\t-T means azimuth should be converted to angles based on map projection\n");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
 		fprintf (stderr, "\t-W sets pen attributes [width = %lgp, color = (%d/%d/%d), texture = solid line].\n", 
@@ -288,7 +288,16 @@ main (int argc, char **argv)
 
 	/* Determine the wesn to be used to read the grdfile */
 
-	GMT_grd_setregion (&h[0], &data_west, &data_east, &data_south, &data_north);
+	if (GMT_grd_setregion (&h[0], &data_west, &data_east, &data_south, &data_north)) {	/* No grid to plot; just do empty map and exit */
+		ps_plotinit (CNULL, gmtdefs.overlay, gmtdefs.page_orientation, gmtdefs.x_origin, gmtdefs.y_origin,
+			gmtdefs.global_x_scale, gmtdefs.global_y_scale, gmtdefs.n_copies,
+			gmtdefs.dpi, GMT_INCH , gmtdefs.paper_width, gmtdefs.page_rgb, GMT_epsinfo (argv[0]));
+		GMT_echo_command (argc, argv);
+		if (gmtdefs.unix_time) GMT_timestamp (argc, argv);
+		GMT_map_basemap ();
+		ps_plotend (gmtdefs.last_page);
+		GMT_end (argc, argv);
+	}
 
 	/* Read data */
 
