@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdview.c,v 1.5 2001/04/11 05:20:49 pwessel Exp $
+ *	$Id: grdview.c,v 1.5.4.8 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -37,7 +37,7 @@
  *				image mask clipping
  * Modified:	07-FEB-2000	3.3.4 - Now works if red = -1 (skips that z-slice)
  * 				Understands patterns in cpt files (-Qs only)
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -91,7 +91,7 @@ main (int argc, char **argv)
 	int	side, way, nm, nm2, nx_f, ny_f, off, nx, ny;
 	int	rgb_facade[3], bin, two, mx, my, sw, se, nw, ne, id, n4, nk;
 	int	c, rgb[3], i_start, i_stop, j_start, j_stop, i_inc, j_inc;
-	int	smooth = 1, tiling = 0, dpi_i = 100;
+	int	smooth = 1, tiling = 0, dpi_i = 100, q_set = 0;
 	
 	BOOLEAN mesh = FALSE, draw_plane = FALSE, facade = FALSE, get_contours, bad, set_z = FALSE;
 	BOOLEAN error = FALSE, outline = FALSE, surface = FALSE, pen_not_set, bilinear = FALSE;
@@ -188,6 +188,7 @@ main (int argc, char **argv)
 					}
 					break;
 				case 'Q':
+					q_set++;
 					switch (argv[i][2]) {
 						case 'm':	/* Mesh plot */
 							mesh = TRUE;
@@ -317,6 +318,14 @@ main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 		
+	if (q_set > 1) {	/* Gave more than one -Q setting */
+		fprintf (stderr, "%s: GMT ERROR:  -Qm, -Qs, and -Qi are mutually exclusive options\n", GMT_program);
+		error++;
+	}	
+	if (tiling && q_set) {	/* Gave both -Q and -T */
+		fprintf (stderr, "%s: GMT ERROR:  -Q and -T are mutually exclusive options\n", GMT_program);
+		error++;
+	}	
 	if (!topofile) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify input file\n", GMT_program);
 		error++;
@@ -405,7 +414,24 @@ main (int argc, char **argv)
 
 	/* Determine the wesn to be used to read the grdfile */
 
-	GMT_grd_setregion (&t_head, &data_west, &data_east, &data_south, &data_north);
+	if (GMT_grd_setregion (&t_head, &data_west, &data_east, &data_south, &data_north)) {	/* No grid to plot; just do empty map and exit */
+		ps_plotinit (CNULL, gmtdefs.overlay, gmtdefs.page_orientation, gmtdefs.x_origin, gmtdefs.y_origin,
+			gmtdefs.global_x_scale, gmtdefs.global_y_scale, gmtdefs.n_copies,
+			gmtdefs.dpi, GMT_INCH , gmtdefs.paper_width, gmtdefs.page_rgb, GMT_epsinfo (argv[0]));
+		GMT_echo_command (argc, argv);
+		if (gmtdefs.unix_time) GMT_timestamp (argc, argv);
+		if (project_info.three_D) {
+			ps_transrotate (-z_project.xmin, -z_project.ymin, 0.0);
+			GMT_map_basemap ();
+			GMT_vertical_axis (2);	/* Draw background axis */
+			ps_rotatetrans (z_project.xmin, z_project.ymin, 0.0);
+		}
+		else
+			GMT_map_basemap ();
+		ps_plotend (gmtdefs.last_page);
+		GMT_end (argc, argv);
+	}
+
 
 	/* Read data */
 
