@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdvolume.c,v 1.4 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: grdvolume.c,v 1.4.4.8 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
  * Author:	Paul Wessel
  * Date:	23-SEP-1997
  * Revised:	02-JUN-1999
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -81,7 +81,7 @@ main (int argc, char **argv)
 				case 'C':
 					contour = TRUE;
 					n = sscanf (&argv[i][2], "%lf/%lf/%lf", &clow, &chigh, &deltac);
-					if (n == 1) chigh = deltac = clow;
+					if (n == 1) chigh = clow, deltac = 1.0;	/* So calculation of ncontours will yield 1 */
 					break;
 				case 'L':
 					base = (argv[i][2]) ? atof (&argv[i][2]) : GMT_d_NaN;
@@ -193,7 +193,7 @@ main (int argc, char **argv)
 		y_size = grd.y_inc;
 	}
 
-	n_contours = (contour) ? irint ((chigh - clow) / deltac) + 1 : 0;
+	n_contours = (contour) ? irint ((chigh - clow) / deltac) + 1 : 1;
 
 	height = (double *) GMT_memory (VNULL, (size_t)n_contours, sizeof (double), GMT_program);
 	vol = (double *) GMT_memory (VNULL, (size_t)n_contours, sizeof (double), GMT_program);
@@ -235,7 +235,7 @@ main (int argc, char **argv)
 				/* Find if a contour goes through this bin */
 
 				for (k = neg = pos = 0, bad = FALSE; !bad && k < 4; k++) {
-					(f[ij+ij_inc[k]] < 0.0) ? neg++ : pos++;
+					(f[ij+ij_inc[k]] <= (float)small) ? neg++ : pos++;
 					if (GMT_is_fnan (f[ij+ij_inc[k]])) bad = TRUE;
 				}
 
@@ -253,6 +253,8 @@ main (int argc, char **argv)
 					if ((f[ij-nx] * f[ij+1-nx]) < 0.0) nc++, cut[2] = TRUE;	/* Crossing the N border */
 					if ((f[ij-nx] * f[ij]) < 0.0)      nc++, cut[3] = TRUE;	/* Crossing the W border */
 
+					if (nc < 2) continue;	/* Can happen if some nodes were 0 and then reset to smal, thus passing the test */
+
 					if (nc == 4) {	/* Saddle scenario */
 						if (f[ij] > 0) {	/* Need both SW and NE triangles */
 							SW_triangle (f, ij, nx, TRUE, &dv, &da);
@@ -338,18 +340,18 @@ main (int argc, char **argv)
 
 	/* Print out final estimates */
 
-        sprintf (format, "%s\t%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+        sprintf (format, "%s\t%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 
 	if (full) {
-		sprintf (format, "%s\t%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%s\t%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		for (c = 0; c < n_contours; c++) fprintf (GMT_stdout, format, clow + c * deltac, area[c], vol[c], height[c]);
 	}
 	else if (contour) {
-        	sprintf (format, "%s\t%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+        	sprintf (format, "%s\t%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (GMT_stdout, format, clow + c * deltac, area[c], vol[c], height[c]);
 	}
 	else {
-        	sprintf (format, "%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+        	sprintf (format, "%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (GMT_stdout, format, area[c], vol[c], height[c]);
 	}
 
