@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: makecpt.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: makecpt.c,v 1.2.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
  *
  * Author:	Walter H.f. Smith & P. Wessel
  * Date:	04-JUL-2000
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -48,7 +48,7 @@ main(int argc, char **argv)
 
 	/* Get list of available color tables in GMT /share */
 
-	sprintf (CPT_lis, "%s%cshare%cGMT_CPT.lis\0", GMTHOME, DIR_DELIM, DIR_DELIM);
+	sprintf (CPT_lis, "%s%cshare%cGMT_CPT.lis", GMTHOME, DIR_DELIM, DIR_DELIM);
 
 	if ((fpc = fopen (CPT_lis, "r")) == NULL) {
 		fprintf (stderr, "%s: ERROR: Cannot open file %s\n", GMT_program, CPT_lis);
@@ -124,7 +124,7 @@ main(int argc, char **argv)
 		if (strstr (table, ".cpt"))
 			strcpy (CPT_file, table);
 		else
-			sprintf (CPT_file, "%s.cpt\0", table);
+			sprintf (CPT_file, "%s.cpt", table);
 
 		ok = !access (CPT_file, R_OK);
 		if (ok && gmtdefs.verbose) fprintf (stderr, "%s: Reading %s in current directory\n", GMT_program, CPT_file);
@@ -132,9 +132,9 @@ main(int argc, char **argv)
 
 	if (!ok)	{	/* No table in current dir, try /share */
 		if (table)
-			sprintf (CPT_file, "%s%cshare%cGMT_%s.cpt\0", GMTHOME, DIR_DELIM, DIR_DELIM, table);
+			sprintf (CPT_file, "%s%cshare%cGMT_%s.cpt", GMTHOME, DIR_DELIM, DIR_DELIM, table);
 		else	/* Default to rainbow colors */
-			sprintf (CPT_file, "%s%cshare%cGMT_rainbow.cpt\0", GMTHOME, DIR_DELIM, DIR_DELIM);
+			sprintf (CPT_file, "%s%cshare%cGMT_rainbow.cpt", GMTHOME, DIR_DELIM, DIR_DELIM);
 
 		ok = !access (CPT_file, R_OK);
 		if (!ok) {
