@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mapproject.c,v 1.4 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: mapproject.c,v 1.4.4.10 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,7 @@
  *
  * Author:	Paul Wessel
  * Date:	1-MAR-1990
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
  
@@ -46,8 +46,8 @@ main (int argc, char **argv)
 	BOOLEAN map_center = FALSE, nofile = TRUE, done = FALSE, first = TRUE;
 	BOOLEAN pure_ascii = FALSE, d_set = FALSE;
 	
-	double west = 0.0, east = 0.0, south = 0.0, north = 0.0;
-	double xmin, xmax, ymin, ymax, *in, *out, utm_correct = 0.0, fwd_scale, inv_scale;
+	double west = 0.0, east = 0.0, south = 0.0, north = 0.0, x_in, y_in;
+	double xmin, xmax, ymin, ymax, *in, *out, fwd_scale, inv_scale;
 	double x_in_min, x_in_max, y_in_min, y_in_max, inch_to_unit, unit_to_inch;
 	double x_out_min, x_out_max, y_out_min, y_out_max, u_scale;
 	
@@ -111,7 +111,7 @@ main (int argc, char **argv)
 	if (argc == 1 || GMT_quick) {
 		fprintf (stderr, "mapproject %s - Forward and Inverse map transformation of 2-D coordinates\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: mapproject <infiles> -J<parameters> -R<west/east/south/north>\n");
-		fprintf (stderr, "\t[-C] [-Dc|i|m|p] [-F[k|m|n|i|c|p]] [-H[<nrec>]] [-I] [-M[<flag>]] [-S] [-V] [-:] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf (stderr, "\t[-C] [-Dc|i|m|p] [-F[k|m|n|i|c|p]] [-H[<nrec>]] [-I] [-M[<flag>]] [-S] [-V] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -176,28 +176,26 @@ main (int argc, char **argv)
 	pure_ascii = !(GMT_io.binary[0] || GMT_io.binary[1]);
 
 	GMT_map_setup (west, east, south, north);
-	
-	/* utm_correct = (project_info.projection == UTM && !project_info.north_pole) ? FALSE_NORTHING : 0.0; */
-	
+		
 	if (gmtdefs.verbose) {
-		sprintf (format, "%s/%s/%s/%s\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%s/%s/%s/%s", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		xmin = (map_center) ? project_info.xmin - project_info.x0 : project_info.xmin;
 		xmax = (map_center) ? project_info.xmax - project_info.x0 : project_info.xmax;
 		ymin = (map_center) ? project_info.ymin - project_info.y0 : project_info.ymin;
-		ymax = (map_center) ? project_info.ymax - project_info.y0 + utm_correct : project_info.ymax;
+		ymax = (map_center) ? project_info.ymax - project_info.y0 : project_info.ymax;
 		if (one_to_one) {	/* Convert to GMT inches */
 			strncpy (unit_name, scale_unit_name, 80);
 			xmin /= project_info.x_scale;
 			xmax /= project_info.x_scale;
-			ymin = (ymin / project_info.y_scale) + utm_correct;
-			ymax = (ymax / project_info.y_scale) + utm_correct;
+			ymin /= project_info.y_scale;
+			ymax /= project_info.y_scale;
 		}
 		
 		/* Convert inches to chosen MEASURE */
-		xmin *= fwd_scale;
-		xmax *= fwd_scale;
-		ymin *= fwd_scale;
-		ymax *= fwd_scale;
+		xmin *= inch_to_unit;
+		xmax *= inch_to_unit;
+		ymin *= inch_to_unit;
+		ymax *= inch_to_unit;
 
 		fprintf (stderr, "%s:  Transform ", GMT_program);
 		fprintf (stderr, format, project_info.w, project_info.e, project_info.s, project_info.n);
@@ -222,7 +220,7 @@ main (int argc, char **argv)
 	else	/* Default to the number of input fields */
 		n_output = &n_expected_fields;
 	
-	sprintf (format1, "%s\t%s\t%%s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format1, "%s\t%s\t%%s\n", gmtdefs.d_format, gmtdefs.d_format);
 	
 	if (n_files > 0)
 		nofile = FALSE;
@@ -275,13 +273,18 @@ main (int argc, char **argv)
 				}
 				if (!out) out = (double *) GMT_memory (VNULL, (size_t)n_expected_fields, sizeof (double), GMT_program);
 
+				if (gmtdefs.xy_toggle) d_swap (in[0], in[1]);		/* Fix to undo swap in GMT_input.  We do this since we want (x,y) -> (lat,lon) when -: is set */
+				if (gmtdefs.verbose) {
+					x_in = in[0];
+					y_in = in[1];
+				}
 				if (one_to_one) {	/* Convert from 1:1 scale */
 					if (unit) {
 						in[0] *= u_scale;
 						in[1] *= u_scale;
 					}
 					in[0] *= project_info.x_scale;
-					in[1] = (in[1] - utm_correct) * project_info.y_scale;
+					in[1] *= project_info.y_scale;
 				}
 				else if (gmtdefs.measure_unit != GMT_INCH) {	/* Convert from whatever to inch */
 					in[0] *= unit_to_inch;
@@ -295,10 +298,10 @@ main (int argc, char **argv)
 				n_read++;
 				if (suppress && GMT_map_outside (out[0], out[1])) continue;
 				if (gmtdefs.verbose) {
-					x_in_min = MIN (x_in_min, in[0]);
-					x_in_max = MAX (x_in_max, in[0]);
-					y_in_min = MIN (y_in_min, in[1]);
-					y_in_max = MAX (y_in_max, in[1]);
+					x_in_min = MIN (x_in_min, x_in);
+					x_in_max = MAX (x_in_max, x_in);
+					y_in_min = MIN (y_in_min, y_in);
+					y_in_max = MAX (y_in_max, y_in);
 					x_out_min = MIN (x_out_min, out[0]);
 					x_out_max = MAX (x_out_max, out[0]);
 					y_out_min = MIN (y_out_min, out[1]);
@@ -348,7 +351,7 @@ main (int argc, char **argv)
 				}
 				if (one_to_one) {	/* Convert to 1:1 scale */
 					out[0] /= project_info.x_scale;
-					out[1] = (out[1] / project_info.y_scale) + utm_correct;
+					out[1] /= project_info.y_scale;
 					if (unit) {
 						out[0] *= u_scale;
 						out[1] *= u_scale;
@@ -379,6 +382,7 @@ main (int argc, char **argv)
 				}
 				else {	/* Simply copy other columns and output */
 					for (k = 2; k < *n_output; k++) out[k] = in[k];
+					if (gmtdefs.xy_toggle) d_swap (out[0], out[1]);		/* Fix since the next line will swap again.  We do this since we want (lat,lon) -> (x,y) when -: is set*/
 					GMT_output (GMT_stdout, *n_output, out);
 				}
 				n++;
@@ -388,9 +392,9 @@ main (int argc, char **argv)
 	}
 	
 	if (gmtdefs.verbose && n_read > 0) {
-		sprintf (format, "%%s: Input extreme values:  Xmin: %s Xmax: %s Ymin: %s Ymax %s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%%s: Input extreme values:  Xmin: %s Xmax: %s Ymin: %s Ymax %s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (stderr, format, GMT_program, x_in_min, x_in_max, y_in_min, y_in_max);
-		sprintf (format, "%%s: Output extreme values:  Xmin: %s Xmax: %s Ymin: %s Ymax %s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%%s: Output extreme values:  Xmin: %s Xmax: %s Ymin: %s Ymax %s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (stderr, format, GMT_program, x_out_min, x_out_max, y_out_min, y_out_max);
 		if (inverse)
 			fprintf (stderr, "%s: Mapped %d x-y pairs [%s] to lon-lat\n", GMT_program, n, unit_name);
