@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: minmax.c,v 1.3 2001/03/01 22:08:26 pwessel Exp $
+ *    $Id: minmax.c,v 1.3.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
  * Author:	Paul Wessel
  * Date:	20-JUN-2000
  * Revised:	20-FEB-2001 BCH-J: Added -D option for dateline discontinuity
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -34,7 +34,7 @@ main (int argc, char **argv)
 	BOOLEAN  error = FALSE, nofile = TRUE, done = FALSE, got_stuff = FALSE, first, step = FALSE, columns = FALSE, give_r_string = FALSE;
 	BOOLEAN  dateline = FALSE;
 
-	double dx, dy, *xyzmin, *xyzmax, west, east, south, north, low, high, *in;
+	double delta[2], *xyzmin, *xyzmax, west, east, south, north, low, high, *in;
 
 	char line[BUFSIZ], file[BUFSIZ], format[BUFSIZ], empty_format[15];
 
@@ -68,7 +68,7 @@ main (int argc, char **argv)
 					GMT_multisegment (&argv[i][2]);
 					break;
 				case 'I':
-					GMT_getinc (&argv[i][2], &dx, &dy);
+					GMT_getinc (&argv[i][2], &delta[0], &delta[1]);
 					step = TRUE;
 					break;
 				case 'L':
@@ -94,7 +94,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "\t-D sets longitude discontinuity to dateline (requires -L)\n");
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-I returns textstring -Rw/e/s/n to nearest multiple of dx/dy (assumes 2+ col data)\n");
-		fprintf (stderr, "\t   If -C is set then the columns are rounded off and no -R string is issued\n");
+		fprintf (stderr, "\t   If -C is set then only the first 2 columns are rounded off and no -R string is issued\n");
 		fprintf (stderr, "\t-L means that x is longitude, i.e. assumed to be periodic in 360\n");
 		GMT_explain_option ('M');
 		GMT_explain_option (':');
@@ -105,7 +105,7 @@ main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 	
-	if (step && (dx <= 0.0 || dy <= 0.0)) {
+	if (step && (delta[0] <= 0.0 || delta[1] <= 0.0)) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -I option.  Must specify positive increment(s)\n", GMT_program);
 		error++;
 	}
@@ -144,14 +144,14 @@ main (int argc, char **argv)
 	
 	if (step && !columns) {
 		give_r_string = TRUE;
-		sprintf (format, "-R%s/%s/%s/%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "-R%s/%s/%s/%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 	}
 	else if (columns) {
-		sprintf (format, "\t%s\t%s\0", gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "\t%s\t%s", gmtdefs.d_format, gmtdefs.d_format);
 		strcpy (empty_format, "\tNaN\tNaN");
 	}
 	else {
-		sprintf (format, "\t<%s/%s>\0", gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "\t<%s/%s>", gmtdefs.d_format, gmtdefs.d_format);
 		strcpy (empty_format, "\t<NaN/NaN>");
 	}
 
@@ -235,25 +235,28 @@ main (int argc, char **argv)
 
 		if (give_r_string && got_stuff) {
 			west  = MIN (west, xyzmin[0]);		east  = MAX (east, xyzmax[0]);
-			south = MIN (south, xyzmin[1]);	north = MAX (north, xyzmax[1]);
+			south = MIN (south, xyzmin[1]);		north = MAX (north, xyzmax[1]);
 		}
 		else if (n > 0) {
 			if (!columns) fprintf (GMT_stdout, "%s: N = %d", file, n);
 			for (i = 0; i < ncol; i++) {
 				if (xyzmin[i] == DBL_MAX)
 					fprintf (GMT_stdout, "%s", empty_format);
-				else {
-					low  = (step) ? floor (xyzmin[i] / dx) * dx : xyzmin[i];
-					high = (step) ? ceil (xyzmax[i] / dx) * dx : xyzmax[i];
+				else if (i < 2) {
+					low  = (step) ? floor (xyzmin[i] / delta[i]) * delta[i] : xyzmin[i];
+					high = (step) ? ceil (xyzmax[i] / delta[i]) * delta[i] : xyzmax[i];
 					fprintf (GMT_stdout, format, low, high);
 				}
+				else {
+					fprintf (GMT_stdout, format, xyzmin[i], xyzmax[i]);
+				}
 			}
 			fprintf (GMT_stdout, "\n");
 		}
 	}
 	if (got_stuff && give_r_string) {
-		west  = floor (west / dx) * dx;		east  = ceil (east / dx) * dx;
-		south = floor (south / dy) * dy;	north = ceil (north / dy) * dy;
+		west  = floor (west / delta[0]) * delta[0];	east  = ceil (east / delta[0]) * delta[0];
+		south = floor (south / delta[1]) * delta[1];	north = ceil (north / delta[1]) * delta[1];
 		fprintf (GMT_stdout, format, west, east, south, north);
 	}
 	else if (!got_stuff)
