@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: nearneighbor.c,v 1.5 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: nearneighbor.c,v 1.5.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
  *
  * Author:	Paul Wessel
  * Date:	14-JUL-2000
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -456,7 +456,7 @@ main (int argc, char **argv)
 	}
 	
 	if (gmtdefs.verbose) {
-		sprintf (line, "%s)\n\0", gmtdefs.d_format);
+		sprintf (line, "%s)\n", gmtdefs.d_format);
 		fprintf (stderr, "%s: %d nodes were assigned an average value\n", GMT_program, n_set);
 		fprintf (stderr, "%s: %d nodes failed sector criteria and %d nodes had no neighbor points (all set to ", GMT_program, n_almost, n_none);
 		(GMT_is_dnan (empty)) ? fprintf (stderr, "NaN)\n") : fprintf (stderr, line, empty);
