@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: project.c,v 1.4 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: project.c,v 1.4.4.10 2004/01/07 20:45:09 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -32,6 +32,7 @@
 		03-NOV-1998	PW: Can read any number of data columns; z in -Fz refers to
 				all these columns in the output.
    Version:	3.4		PW: Fixed problem with small circle distances
+   Version:	3.4.3
 */
 
 #include "gmt.h"
@@ -224,7 +225,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "project %s - project data onto line or great circle, generate track, or translate coordiantes\n\n", GMT_VERSION);
 		fprintf(stderr,"usage:	project [files] -C<ox>/<oy> [-A<azimuth>] [-D<d_or_g>] [-E<bx>/<by>]\n");
 		fprintf(stderr,"\t[-F<flags>] [-G<dist>] [-H[<nrec>]] [-L[w][<l_min>/<l_max>]] [-M[<flag>]] [-N] [-Q] [-S]\n");
-		fprintf(stderr,"\t[-T<px>/<py>] [-V] [-W<w_min>/<w_max>] [-:] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf(stderr,"\t[-T<px>/<py>] [-V] [-W<w_min>/<w_max>] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 
@@ -254,6 +255,7 @@ main (int argc, char **argv)
 		fprintf(stderr,"\t  p,q may be scaled from degrees into kilometers by the -Q option.  See -L, -Q, -W.\n");
 		fprintf(stderr,"\t  Note z refers to all input data columns beyond the required x,y\n");
 		fprintf(stderr,"\t  [Default is all fields, i.e. -Fxyzpqrs]\n");
+		fprintf(stderr,"\t  If -G is set, -F is not available and output defaults to rsp\n");
 		fprintf(stderr,"\t-G means Generate (r,s,p) points along profile every <dist> units. (No input data used.)\n");
 		fprintf(stderr,"\t   If E given, will generate from C to E; else must give -L<l_min>/<l_max> for length.\n");
 		GMT_explain_option ('H');
@@ -317,6 +319,10 @@ main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -G option: Must also specify -Lmin/max or use -E instead\n", GMT_program);
 		error++;
 	}
+	if ( generate && n_outputs > 0) {	/* -F not allowed with -G  */
+		fprintf (stderr, "%s: GMT SYNTAX ERROR -G option: -F not allowed [Defaults to rsp]\n", GMT_program);
+		error++;
+	}
 	if ( generate && d_inc <= 0.0) {	/* No increment given  */
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -G option: Must specify a positive increment\n", GMT_program);
 		error++;
@@ -900,8 +906,8 @@ void	flat_project_setup(double alat, double alon, double blat, double blon, doub
 	}
 	
 	e[0] = e[3] = cos(*azim);
-	e[1] = sin(*azim);
-	e[3] = -e[1];
+	e[2] = sin(*azim);
+	e[1] = -e[2];
 }
 
 void copy_text_from_col3 (char *line, char *z_cols)
