@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psbasemap.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: psbasemap.c,v 1.3.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
  *
  * Author:	Paul Wessel
  * Date:	08-JUL-2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
  
@@ -45,7 +45,11 @@ main (int argc, char **argv)
 	argc = GMT_begin (argc, argv);
 		
 	for (i = 1; i < argc; i++) {
-		if (argv[i][0] != '-') error = TRUE;
+		if (argv[i][0] != '-') {
+			error = TRUE;
+			fprintf (stderr, "%s: GMT SYNTAX ERROR:  Options must start with leading -. Your argument \"%s\" is unrecognized\n", GMT_program, argv[i]);
+			continue;
+		}
 		
 		switch (argv[i][1]) {
 		
