@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psclip.c,v 1.3 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: psclip.c,v 1.3.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
  *
  * Author:	Paul Wessel
  * Date:	6-FEB-1991-2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
 
@@ -228,7 +228,7 @@ main (int argc, char **argv)
 
 			if (!nofile && gmtdefs.verbose) {
 				fprintf (stderr, "%s: Working on file %s\n", GMT_program, argv[fno]);
-				sprintf (line, "File: %s\0", argv[fno]);
+				sprintf (line, "File: %s", argv[fno]);
 				ps_comment (line);
 			}
 			if (gmtdefs.io_header) for (i = 0; i < gmtdefs.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
