@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pscoast.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: pscoast.c,v 1.3.4.9 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -47,7 +47,7 @@
  *
  * Author:	Paul Wessel
  * Date:	24-JUN-2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
 
@@ -180,7 +180,7 @@ main (int argc, char **argv)
 						continue;
 					}
 					draw_border = TRUE;
-					strncpy(key, "\0", 5);
+					memset ((void *)key, 0, (size_t)5);
 					for (k = 2; argv[i][k] && argv[i][k] != '/'; k++);
 					if (argv[i][k] && argv[i][k] == '/') {	/* Specified pen args */
 						strncpy (key, &argv[i][2], (size_t)k-2);
@@ -222,7 +222,7 @@ main (int argc, char **argv)
 						continue;
 					}
 					draw_river = TRUE;
-					strncpy(key, "\0", 5);
+					memset ((void *)key, 0, (size_t)5);
 					for (k = 2; argv[i][k] && argv[i][k] != '/'; k++);
 					if (argv[i][k] && argv[i][k] == '/') {	/* Specified pen args */
 						strncpy (key, &argv[i][2], (size_t)k-2);
@@ -312,7 +312,7 @@ main (int argc, char **argv)
 		fprintf (stderr,"usage: pscoast -J<params> -R<west>/<east>/<south>/<north> [-A<min_area>[/<min_level>/<max_level>]] [-B<tickinfo>]\n");
 		fprintf (stderr, "\t[-C[<fill>]] [-D<resolution>] [-Eaz/el] [-G[<fill>]] [-I<feature>[/<pen>]]\n");
 		fprintf (stderr, "\t[-K] [-L[f][x]<lon0>/<lat0>/<slat>/<length>[m|n|k]] [-M[<flag>]] [-N<feature>[/<pen>]] [-O] [-P] [-Q]\n");
-		fprintf (stderr, "\t[-S<fill>] [-U[dx/dy/][label]] [-V] [-W[<pen>]] [-X<x_shift>] [-Y<y_shift>] [-bo[s]] [-c<ncopies>]\n");
+		fprintf (stderr, "\t[-S<fill>] [-U[dx/dy/][label]] [-V] [-W[<pen>]] [-X<x_shift>] [-Y<y_shift>] [-bo[s][<n>]] [-c<ncopies>]\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -562,7 +562,7 @@ main (int argc, char **argv)
 		}
 	}
 
-	if (possibly_donut_hell && !clobber_background) {	/* Force clobber when donuts may be called for now */
+	if (possibly_donut_hell && paint_polygons && !clobber_background) {	/* Force clobber when donuts may be called for now */
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Warning: -JE requires oceans to be painted first\n", GMT_program);
 		clobber_background = TRUE;
 		recursive = FALSE;
@@ -632,7 +632,7 @@ main (int argc, char **argv)
 		
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Working on block # %5d\r", GMT_program, bin);
 		if (!dumping) {
-			sprintf (comment, "Bin # %d\0", bin);
+			sprintf (comment, "Bin # %d", bin);
 			ps_comment (comment);
 		}
 
@@ -720,7 +720,7 @@ main (int argc, char **argv)
 		
 			for (i = 0; i < np; i++) {
 				if (dumping) {
-					sprintf (GMT_io.segment_header, "%c Shore Bin # %d, Level %d\n\0", GMT_io.EOF_flag, bin, p[i].level);
+					sprintf (GMT_io.segment_header, "%c Shore Bin # %d, Level %d\n", GMT_io.EOF_flag, bin, p[i].level);
 					GMT_write_segmentheader (GMT_stdout, 2);
 					for (k = 0; k < p[i].n; k++) {
 						out[0] = p[i].lon[k];
@@ -744,7 +744,7 @@ main (int argc, char **argv)
 	}
 	if (need_coast_base) GMT_shore_cleanup (&c);
 
-	if (clipping && did_clip) ps_clipon (p[k].lon, p[k].lat, 0, GMT_no_rgb, 2);	/* Dummy to end path */
+	if (clipping && did_clip) ps_clipon ((double *)NULL, (double *)NULL, 0, GMT_no_rgb, 2);	/* Dummy to end path */
 
 	if (gmtdefs.verbose) fprintf (stderr, "\n");
 	
@@ -770,7 +770,7 @@ main (int argc, char **argv)
 			
 			for (i = 0; i < np; i++) {
 				if (dumping) {
-					sprintf (GMT_io.segment_header, "%c River Bin # %d, Level %d\n\0", GMT_io.EOF_flag, bin, p[i].level);
+					sprintf (GMT_io.segment_header, "%c River Bin # %d, Level %d\n", GMT_io.EOF_flag, bin, p[i].level);
 					GMT_write_segmentheader (GMT_stdout, 2);
 					for (k = 0; k < p[i].n; k++) {
 						out[0] = p[i].lon[k];
@@ -832,7 +832,7 @@ main (int argc, char **argv)
 
 			for (i = 0; i < np; i++) {
 				if (dumping) {
-					sprintf (GMT_io.segment_header, "%c Border Bin # %d, Level %d\n\0", GMT_io.EOF_flag, bin, p[i].level);
+					sprintf (GMT_io.segment_header, "%c Border Bin # %d, Level %d\n", GMT_io.EOF_flag, bin, p[i].level);
 					GMT_write_segmentheader (GMT_stdout, 2);
 					for (k = 0; k < p[i].n; k++) {
 						out[0] = p[i].lon[k];
@@ -897,7 +897,7 @@ void recursive_painting (int k0, int np, struct POL p[], int level, int start_le
 		if (p[k].n == 0 || p[k].level < level) continue;
 		go = (p[k].level == level) ? ((k0 == -1) ? TRUE : GMT_non_zero_winding (p[k].lon[0], p[k].lat[0], p[k0].lon, p[k0].lat, p[k0].n)) : FALSE;
 		if (go) {
-			sprintf (text, "Polygon %d\0", k);
+			sprintf (text, "Polygon %d", k);
 			ps_comment (text);
 			ps_clipon (p[k].lon, p[k].lat, p[k].n, GMT_no_rgb, flag);
 			recursive_painting (k, np, p, level+1, start_level, fill);
@@ -921,7 +921,7 @@ void recursive_clipping (int k0, int np, struct POL *p, int level, int start_lev
 		if (p[k].n == 0 || p[k].level < level) continue;
 		go = (p[k].level == level) ? ((k0 == -1) ? TRUE : GMT_non_zero_winding (p[k].lon[0], p[k].lat[0], p[k0].lon, p[k0].lat, p[k0].n)) : FALSE;
 		if (go) {
-			sprintf (text, "Polygon %d\0", k);
+			sprintf (text, "Polygon %d", k);
 			ps_comment (text);
 			flag = (*n_pieces == 0) ? 1 : 0;
 			(*n_pieces)++;
