@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pscontour.c,v 1.4 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: pscontour.c,v 1.4.4.11 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
  *
  * Author:	Paul Wessel
  * Date:	1-JAN-1995
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -68,7 +68,6 @@ struct LABEL {
 	
 int get_triangle_crossings(double *x, double *y, double *z, int *ind, double **xc, double **yc, double **zc, int **v, int **cindex);
 void draw_contour(double *xx, double *yy, int nn, double cval, char ctype, double cangle, int closed, double gap), plot_labels(int size, int box, int rgb[]);
-void dump_contour(double *xx, double *yy, int nn, double cval, int id, BOOLEAN interior, char *file);
 void paint_it (double x[], double y[], int n, double z);
 
 main(int argc, char **argv)
@@ -218,7 +217,7 @@ main(int argc, char **argv)
 		fprintf (stderr,"usage: pscontour <xyzfile> -C<cpt_file> -J<params> -R<west>/<east>/<south>/<north>\n");
 		fprintf (stderr, "\t[-A[-][f<fontsize>][/r/g/b][a<angle>][o]] [-B<tickinfo>] [-D<dumpfile>] [-E<az>/<el>] [-G<gap>]\n");
 		fprintf (stderr, "\t[-H[<nrec>]] [-I] [-K] [-L<pen>] [-M[<flag>]] [-N] [-O] [-P] [-T<indexfile>]\n");
-		fprintf (stderr, "\t[-U] [-V] [-W[+]<pen>] [-X<x_shift>] [-Y<y_shift>] [-c<ncopies>] [-:] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf (stderr, "\t[-U] [-V] [-W[+]<pen>] [-X<x_shift>] [-Y<y_shift>] [-c<ncopies>] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -465,8 +464,15 @@ main(int argc, char **argv)
 		
 		if (image_them) {	/* Must color the triangle slices according to cpt file */
 		
-			if (nx == 0) {	/* No contours go through - easy */
-				paint_it (xx, yy, 3, zz[0]);	/* Any z will do */
+			if (nx == 0) {	/* No contours go through - easy, but must check for NaNs */
+				int kzz;
+				double zzz;
+				for (k = kzz = 0, zzz = 0.0; k < 3; k++) {
+					if (GMT_is_dnan (zz[k])) continue;
+					zzz += zz[k];
+					kzz++;
+				}
+				if (kzz) paint_it (xx, yy, 3, zzz / kzz);
 			}
 			else {	/* Must paint all those slices separately */
 			
@@ -709,7 +715,7 @@ main(int argc, char **argv)
 				}
 
 				draw_contour (xp, yp, n, cont[c].val, cont[c].type, cont[c].angle, close, anot_dist);
-				if (dump) dump_contour (xp, yp, n, cont[c].val, section++, close, dfile);
+				if (dump) GMT_dump_contour (xp, yp, n, cont[c].val, section++, close, dfile);
 
 				GMT_free ((void *)xp);
 				GMT_free ((void *)yp);
@@ -749,6 +755,8 @@ int get_triangle_crossings (double *x, double *y, double *z, int *ind, double **
 	xx[1] = x[ind[1]];	yy[1] = y[ind[1]];	zz[1] = z[ind[1]];
 	xx[2] = x[ind[2]];	yy[2] = y[ind[2]];	zz[2] = z[ind[2]];
 
+	if (GMT_is_dnan (zz[0]) || GMT_is_dnan (zz[1]) || GMT_is_dnan (zz[2])) return (0);	/* Cannot have crossings if NaNs are present */
+
 	zmin = MIN (zz[0], MIN (zz[1], zz[2]));	/* Min z vertex */
 	zmax = MAX (zz[0], MAX (zz[1], zz[2]));	/* Max z vertex */
 	
@@ -818,7 +826,7 @@ void draw_contour (double *xx, double *yy, int nn, double cval, char ctype, doub
 	
 	if (nn < 2) return;
 		
-	sprintf (format, "%lg contour\0", cval);
+	sprintf (format, "%lg contour", cval);
 	ps_comment (format);
 	
 	ps_line (xx, yy, nn, 3, closed, TRUE);
@@ -894,42 +902,6 @@ void plot_labels (int size, int box, int rgb[])
 	}
 }
 
-void dump_contour (double *xx, double *yy, int nn, double cval, int id, BOOLEAN interior, char *file)
-{
-	int i;
-	double out[3];
-	char fname[BUFSIZ], format[80], suffix[4];
-	FILE *fp;
-	
-	if (nn < 2) return;
-	
-	out[2] = cval;
-	(GMT_io.binary[1]) ? strcpy (suffix, "b") : strcpy (suffix, "xyz");
-	sprintf (format, "%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
-	if (!GMT_io.binary[1] && GMT_io.multi_segments) {
-		if (GMT_io.multi_segments == 2) {	/* Must create file the first time around */
-			fp = GMT_fopen (file, "w");
-			GMT_io.multi_segments = TRUE;
-		}
-		else	/* Later we append to it */
-			fp = GMT_fopen (file, "a+");
-		sprintf (GMT_io.segment_header, "%c %lg contour\0", GMT_io.EOF_flag, cval);
-		GMT_write_segmentheader (fp, 3);
-	}
-	else {
-		if (interior)
-			sprintf (fname, "%s_%lg_%d_i.%s\0", file, cval, id, suffix);
-		else
-			sprintf (fname, "%s_%lg_%d.%s\0", file, cval, id, suffix);
-		fp = GMT_fopen (fname, GMT_io.w_mode);
-	}
-	for (i = 0; i < nn; i++) {
-		GMT_xy_to_geo (&out[0], &out[1], xx[i], yy[i]);
-		GMT_output (fp, 3, out);
-	}
-	GMT_fclose (fp);
-}
-
 void paint_it (double x[], double y[], int n, double z) {
 	int index, k, rgb[3];
 	struct GMT_FILL *f;
