@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pshistogram.c,v 1.4 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: pshistogram.c,v 1.4.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
  * Updated to v3.1 13-Jun-1998 Paul Wessel
  * Updated to v3.3 23-Apr-1999 Paul Wessel
  *		     Now uses two passes to get accurate mean and stdev
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -39,7 +39,7 @@
 #define LOG10_COUNTS 4
 #define LOG10_FREQ_PCT 5
 
-double	yy0, yy1, xmin, xmax;
+double	yy0, yy1, x_min, x_max;
 
 float	*x;
 int	*boxh;
@@ -284,21 +284,21 @@ main (int argc, char **argv)
 	}
 	
 	if (gmtdefs.verbose) {
-		sprintf (format, "%%s: Extreme values of the data :\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%%s: Extreme values of the data :\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (stderr, format, GMT_program, x[0], x[n-1]);
-		sprintf (format, "%%s: Locations: L2, L1, LMS; Scales: L2, L1, LMS\t%s\t%s\t%s\t%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%%s: Locations: L2, L1, LMS; Scales: L2, L1, LMS\t%s\t%s\t%s\t%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (stderr, format, GMT_program, stats[0], stats[1], stats[2], stats[3], stats[4], stats[5]);
 	}
 	
 	if (west == east) {	/* Set automatic x range [ and tickmarks] */
 		if (frame_info.anot_int[0] == 0.0) {
-			tmp = pow (10.0, floor (d_log10 (xmax-xmin)));
-			if (((xmax-xmin) / tmp) < 3.0) tmp *= 0.5;
+			tmp = pow (10.0, floor (d_log10 (x_max-x_min)));
+			if (((x_max-x_min) / tmp) < 3.0) tmp *= 0.5;
 		}
 		else
 			tmp = frame_info.anot_int[0];
-		west = floor (xmin / tmp) * tmp;
-		east = ceil (xmax / tmp) * tmp;
+		west = floor (x_min / tmp) * tmp;
+		east = ceil (x_max / tmp) * tmp;
 		if (frame_info.anot_int[0] == 0.0) {
 			frame_info.anot_int[0] = frame_info.frame_int[0] = tmp;
 			frame_info.plot = TRUE;
@@ -311,15 +311,15 @@ main (int argc, char **argv)
 	}
 	
 	if (gmtdefs.verbose) {
-		sprintf (format, "\n%%s: min/max values are :\t%s\t%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
-		fprintf (stderr, format, GMT_program, xmin, xmax, yy0, yy1);
+		sprintf (format, "\n%%s: min/max values are :\t%s\t%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		fprintf (stderr, format, GMT_program, x_min, x_max, yy0, yy1);
 	}
 	
 	if (inquire) {	/* Only info requested, quit before plotting */
 		if (dump_boxes) {
 			int ibox;
 			double xx, yy;
-			sprintf (format, "%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+			sprintf (format, "%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format);
 			for (ibox = 0; ibox < n_boxes; ibox++) {
 				if (boxh[ibox] == 0) continue;
 				xx = west + ibox * box_width;
@@ -369,7 +369,7 @@ main (int argc, char **argv)
 	}
 	
 	if (automatic && gmtdefs.verbose) {
-		sprintf (format, "%%s: Use w/e/s/n = %s/%s/%s/%s and x-tick/y-tick = %s/%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%%s: Use w/e/s/n = %s/%s/%s/%s and x-tick/y-tick = %s/%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (stderr, format, GMT_program, west, east, south, north, frame_info.anot_int[0], frame_info.anot_int[1]);
 	}
 
@@ -421,7 +421,7 @@ int	read_data (void) {
 	x = (float *) GMT_memory (VNULL, (size_t)n_alloc , sizeof (float), GMT_program);
 	
 	n = 0;
-	xmin = DBL_MAX;	xmax = -DBL_MAX;
+	x_min = DBL_MAX;	x_max = -DBL_MAX;
 	n_expected_fields = (GMT_io.ncol[0]) ? GMT_io.ncol[0] : 1 + second;
 	
 	if (gmtdefs.io_header) for (i = 0; i < gmtdefs.n_header_recs; i++) GMT_fgets (buffer, BUFSIZ, fp_in);
@@ -440,8 +440,8 @@ int	read_data (void) {
 			n_alloc += GMT_CHUNK;
 			x = (float *) GMT_memory ((void *)x, (size_t) n_alloc, sizeof (float), GMT_program);
 		}
-		xmin = MIN (xmin, x[n-1]);
-		xmax = MAX (xmax, x[n-1]);
+		x_min = MIN (x_min, x[n-1]);
+		x_max = MAX (x_max, x[n-1]);
 	}
 	
 	if (gmtdefs.verbose) {
