@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psimage.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: psimage.c,v 1.3.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  *
  * Author:	Paul Wessel
  * Date:	28-JUN-2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
 
@@ -210,6 +210,19 @@ main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	if (f_rgb[0] < 0 || b_rgb[0] < 0) {
+		colorize = FALSE;
+		invert = !invert;
+		if (f_rgb[0] < 0) {
+			polarity = 1;	/* 0 + 1 */
+			rgb = b_rgb;
+		}
+		else {
+			polarity = 2;	/* 1 + 1 */
+			rgb = f_rgb;
+		}
+	}
+
 	picture = ps_loadraster (file, &header, invert, monochrome, colorize, f_rgb, b_rgb);
 
 	if (!picture) {
@@ -217,18 +230,6 @@ main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 	
-	if (f_rgb[0] < 0 || b_rgb[0] < 0) {
-		colorize = FALSE;
-		if (f_rgb[0] < 0) {
-			polarity = 1;	/* 0 + 1 */
-			rgb = f_rgb;
-		}
-		else {
-			polarity = 2;	/* 1 + 1 */
-			rgb = b_rgb;
-		}
-	}
-
 	if (!project_info.x_off_supplied && gmtdefs.overlay) gmtdefs.x_origin = 0.0;	/* Since map_setup is not called here */
 	if (!project_info.y_off_supplied && gmtdefs.overlay) gmtdefs.y_origin = 0.0;
 
