@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pslib.h,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: pslib.h,v 1.2.4.5 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * This include file must be included by all programs using pslib.a
  *
  * Author:	Paul Wessel
- * Version:	3.4
+ * Version:	3.4.3
  * Date:	10-OCT-2000
  */
 
