@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psmask.c,v 1.4 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: psmask.c,v 1.4.4.8 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
  *
  * Author:	Paul Wessel
  * Date:	01-JUL-2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
 
@@ -53,7 +53,7 @@ double *x_grid, *y_grid;
 
 void draw_clip_contours (double *xx, double *yy, int nn, int rgb[], int id, int flag);
 void dump_clip_countours (double *xx, double *yy, int nn, int id, char *file);
-void shrink_clip_contours (double *x, double *y, int n);
+void shrink_clip_contours (double *x, double *y, int n, double w, double e);
 int trace_clip_contours (char *grd, int nx, int *edge, double west, double north, double dx, double dy, double xinc2, double yinc2, double **xx, double **yy, int i, int j, int kk, int *max);
 int clip_contours (char *grd, int nx, int ny, double west, double north, double dx, double dy, double xinc2, double yinc2, int *edge, int first, double **x, double **y, int *max);
 
@@ -164,7 +164,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "usage: psmask <xyz-file> -I<xinc>[m|c][/<yinc>[m|c]] -J<params> -R<west/east/south/north>\n");
 		fprintf (stderr, "\t[-B<tickinfo>] [-C] -D<file> [-Eaz/el] [-F] [-G<fill>] [-H[<nrec>]] [-K] [-M[<flag>]]\n");
 		fprintf (stderr, "\t[-N] [-O] [-P] [-S<radius>[k]] [-T] [-U[<label>]] [-V] [-X<x_shift>] [-Y<y_shift>]\n");
-		fprintf (stderr, "\t[-c<ncopies>][ -:] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf (stderr, "\t[-c<ncopies>][ -:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -386,7 +386,7 @@ main (int argc, char **argv)
 			section = 0;
 			first = TRUE;
 			while ((n = clip_contours (grd, nx, ny, west, north, dx, dy, xinc2, yinc2, edge, first, &x, &y, &n_alloc)) > 0) {
-				shrink_clip_contours (x, y, n);
+				shrink_clip_contours (x, y, n, west, east);
 				if (dump) dump_clip_countours (x, y, n, section, dfile);
 				draw_clip_contours (x, y, n, fill.rgb, section, first);
 				first = FALSE;
@@ -474,12 +474,12 @@ void draw_clip_contours (double *xx, double *yy, int nn, int rgb[], int id, int
 	if (project_info.three_D) GMT_2D_to_3D (xx, yy, nn);
 	
 	if (nn > 0) {
-		sprintf (comment, "Start of clip path sub-segment %d\0", id);
+		sprintf (comment, "Start of clip path sub-segment %d", id);
 		ps_comment (comment);
 	}
 	ps_clipon (xx, yy, nn, rgb, flag);
 	if (nn > 0) {
-		sprintf (comment, "End of clip path sub-segment %d\0", id);
+		sprintf (comment, "End of clip path sub-segment %d", id);
 		ps_comment (comment);
 	}		
 }
@@ -494,9 +494,9 @@ void dump_clip_countours (double *xx, double *yy, int nn, int id, char *file)
 	if (nn < 2) return;
 	
 	if (GMT_io.binary[1])
-		sprintf (fname, "%s_%d.b\0", file, id);
+		sprintf (fname, "%s_%d.b", file, id);
 	else
-		sprintf (fname, "%s_%d.xy\0", file, id);
+		sprintf (fname, "%s_%d.xy", file, id);
 
 	if ((fp = GMT_fopen (fname, GMT_io.w_mode)) == NULL) {
 		fprintf (stderr, "%s: Unable to create file %s - exiting\n", GMT_program, fname);
@@ -678,16 +678,16 @@ int trace_clip_contours (char *grd, int nx, int *edge, double west, double north
 	return (n);
 }
 
-void shrink_clip_contours (double *x, double *y, int n)
+void shrink_clip_contours (double *x, double *y, int n, double w, double e)
 {
 	/* Moves outside points to boundary */
 	int i;
 
 	for (i = 0; i < n; i++) {
-		if (x[i] < project_info.w)
-			x[i] = project_info.w;	
-		if (x[i] > project_info.e)
-			x[i] = project_info.e;
+		if (x[i] < w)
+			x[i] = w;	
+		if (x[i] > e)
+			x[i] = e;
 		if (y[i] < project_info.s)
 			y[i] = project_info.s;
 		if (y[i] > project_info.n)
