@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psrose.c,v 1.4 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: psrose.c,v 1.4.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
  *
  * Author:	Paul Wessel
  * Date:	20-JUN-2000
- * Version:	3.4
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -390,7 +390,7 @@ main (int argc, char **argv)
 	
 	if (inquire || gmtdefs.verbose) {
 		if (file) strcpy (text, file); else strcpy (text, "<stdin>");
-		sprintf (format, "%%s: Info for %%s: n = %%d rmax = %s mean r/az = (%s/%s) totlength = %s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf (format, "%%s: Info for %%s: n = %%d rmax = %s mean r/az = (%s/%s) totlength = %s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (stderr, format, GMT_program, text, n, max, mean_radius, mean_theta, total);
 		if (inquire) {
 			GMT_free ((void *)sum);
@@ -559,10 +559,10 @@ main (int argc, char **argv)
 		
 		if (half_only) {
 			int which;
-			which = (gmtdefs.degree_format >= 10);	/* 0 is small [Default], 1 is large */
-			sprintf (lw, "90%sW\0", GMT_degree_symbol[which]);
-			sprintf (le, "90%sE\0", GMT_degree_symbol[which]);
-			sprintf (ln, "0%s\0", GMT_degree_symbol[which]);
+			which = (gmtdefs.degree_format >= 100);	/* 0 is small [Default], 1 is large */
+			sprintf (lw, "90%sW", GMT_degree_symbol[which]);
+			sprintf (le, "90%sE", GMT_degree_symbol[which]);
+			sprintf (ln, "0%s", GMT_degree_symbol[which]);
 			y = -(3.0 * gmtdefs.anot_offset + GMT_font_height[gmtdefs.anot_font] * asize);
 			if (frame_info.label[0][0]) GMT_text3d (0.0, y, project_info.z_level, gmtdefs.label_font_size, gmtdefs.label_font, frame_info.label[0], 0.0, 10, 0);
 			y = -(5.0 * gmtdefs.anot_offset + GMT_font_height[gmtdefs.anot_font] * lsize + GMT_font_height[gmtdefs.label_font] * lsize);
