@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psscale.c,v 1.4 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: psscale.c,v 1.4.4.8 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@
  *		3.3.2 15-SEP-1999. PW: Fixed bad loop for -Z
  *		3.3.4 21-JAN-2000. PW: Now paint rectangles for discrete cpt files
  *		      08-FEB-2000. PW: Also understand patterns for discrete cpt files
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
 
@@ -157,7 +157,7 @@ main(int argc, char **argv)
 		fprintf (stderr, "\t   Optionally, append triangle height [Default scales with barwidth]\n");
 		fprintf (stderr, "\t-I add illumination for +- <max_intens> [1.0]\n");
 		GMT_explain_option ('K');
-		fprintf (stderr, "\t-L For equal-sized color rectangles\n");
+		fprintf (stderr, "\t-L For equal-sized color rectangles. -B interval, if set, is ignored\n");
 		fprintf (stderr, "\t-M force monochrome colorbar using YIQ transformation\n");
 		fprintf (stderr, "\t-N effective dots-per-inch for color scale [300]\n");
 		GMT_explain_option ('O');
@@ -195,6 +195,8 @@ main(int argc, char **argv)
 	      
 	if (error) exit (EXIT_FAILURE);
 
+	if (equi && B_set) B_set = FALSE;	/* -L overrides intervals set with -B */
+
 	GMT_put_history (argc, argv);	/* Update .gmtcommands */
 
 	if (gmtdefs.verbose) {
@@ -249,7 +251,7 @@ main(int argc, char **argv)
 	/* Because psscale uses -D to position things we need to make some
 	 * changes so that BoundingBox and others are set ~correctly */
 
-	sprintf (text, "X%lg/%lg\0", length, width);
+	sprintf (text, "X%lgi/%lgi", length, width);
 	GMT_map_getproject (text);	/* Fake linear projection */
 	GMT_map_setup (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, width);
 
@@ -525,8 +527,8 @@ void GMT_draw_colorbar (double length, double width, double *z_width, BOOLEAN ho
 				x0 = x1;
 			}
 		}
-		sprintf (text, "%d\0", (int)fabs (floor (GMT_lut[0].z_low)));
-		sprintf (test, "%d\0", (int)fabs (ceil (GMT_lut[GMT_n_colors-1].z_high)));
+		sprintf (text, "%d", (int)fabs (floor (GMT_lut[0].z_low)));
+		sprintf (test, "%d", (int)fabs (ceil (GMT_lut[GMT_n_colors-1].z_high)));
 		off = ((MAX ((int)strlen (text), (int)strlen (test)) + ndec) * 0.49 + ((ndec > 0) ? 0.3 : 0.0) + ((GMT_lut[0].z_low < 0.0) ? 0.3 : 0.0))
 			* gmtdefs.anot_font_size * GMT_u2u[GMT_PT][GMT_INCH];
 		anot_off = -(((len > 0.0) ? len : 0.0) + gmtdefs.anot_offset + off);
@@ -650,9 +652,9 @@ void fix_format (char *unit, char *format)
 			text[j] = 0;
 		}
 		if (text[0] == '-')	/* No space between anotation and unit */
-			sprintf (new_format, "%s%s\0", format, &text[1]);
+			sprintf (new_format, "%s%s", format, &text[1]);
 		else		/* 1 space between anotation and unit */
-			sprintf (new_format, "%s %s\0", format, text);
+			sprintf (new_format, "%s %s", format, text);
 		strcpy (format, new_format);
 	}
 }
