@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pstext.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: pstext.c,v 1.2.4.10 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
  * Version:	3.1 based on old 3.0
  * Version:	3.3: PW: Introducing paragraph mode -M
  * Version:	3.3.4: PW: Input x,y can be in dd:mm[:ss] format
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
 
@@ -65,6 +65,7 @@ main(int argc, char **argv)
 	
 	BOOLEAN error = FALSE, nofile = TRUE, outline = FALSE, set_z = FALSE, master_record = FALSE, offset_outward = FALSE;
 	BOOLEAN solid = TRUE, do_paragraphs = FALSE, list = FALSE, done = FALSE, clip = TRUE, old_GMT_world_map, add;
+	BOOLEAN skip_text_records = FALSE;
 	
 	char text[BUFSIZ], line[BUFSIZ], this_font[80], just_key[5], txt_a[32], txt_b[32], txt_x[32], txt_y[32];
 	char *p, **word, pjust;
@@ -359,7 +360,7 @@ main(int argc, char **argv)
 
 	if (do_paragraphs) {
 		n_alloc = GMT_CHUNK;
-		word = (char **) GMT_memory (VNULL, n_alloc, sizeof (char), GMT_program);
+		word = (char **) GMT_memory (VNULL, n_alloc, sizeof (char *), GMT_program);
 	}
 
 	old_GMT_world_map = GMT_world_map;
@@ -386,6 +387,7 @@ main(int argc, char **argv)
 			if (do_paragraphs) {	/* Paragraph mode */
 				if (line[0] == GMT_io.EOF_flag) {
 
+					skip_text_records = FALSE;
 					if (n_processed) {	/* Must output what we got */
 						GMT_putwords (plot_x, plot_y, word, n_words, &T);
 						n_processed = n_words = 0;
@@ -404,8 +406,10 @@ main(int argc, char **argv)
 					}
 					GMT_geo_to_xy (xy[0], xy[1], &plot_x, &plot_y);
 					if (clip) {
+						skip_text_records = TRUE;	/* If this record should be skipped we must skip the whole paragraph */
 						GMT_map_outside (xy[0], xy[1]);
 						if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
+						skip_text_records = FALSE;	/* Since we got here we do not want to skip */
 					}
 					T.text_justify = (int)pjust;
 					T.block_justify = (isdigit ((int)just_key[0])) ? atoi (just_key) : GMT_just_decode (just_key);
@@ -416,7 +420,7 @@ main(int argc, char **argv)
 					if (this_font[0] >= '0' && this_font[0] <= '9')	/* Gave a font # */
 						T.paragraph_font = atoi (this_font);
 					else {	/* Gave a font name */
-						T.paragraph_font = GMT_key_lookup (&this_font[1], GMT_font_name, N_FONTS);
+						T.paragraph_font = GMT_key_lookup (this_font, GMT_font_name, N_FONTS);
 						if (T.paragraph_font == N_FONTS) {
 							fprintf (stderr, "%s: Record %d had bad font (set to %s (0))\n", GMT_program, n_read, GMT_font_name[0]);
 							T.paragraph_font = 0;
@@ -431,6 +435,7 @@ main(int argc, char **argv)
 					master_record = TRUE;
 				}
 				else {	/* Text block record */
+					if (skip_text_records) continue;	/* Skip all records for this paragraph */
 					if (!master_record) {
 						fprintf (stderr, "%s: Text record line %d not preceeded by paragraph information, must exit)\n", GMT_program, n_read);
 						exit (EXIT_FAILURE);
@@ -464,6 +469,7 @@ main(int argc, char **argv)
 				n_read++;
 			}
 			else {	/* Old-style pstext input */
+				if (skip_text_records) continue;	/* Skip all records for this paragraph */
 				nscan = sscanf (line, "%s %s %d %lf %s %s %[^\n]\n", txt_x, txt_y, &T.font_size, &T.paragraph_angle, this_font, just_key, text);
 				if (!(GMT_scanf (txt_x, &xy[ix]) && GMT_scanf (txt_y, &xy[iy]))) {
 					fprintf (stderr, "%s: Record %d had bad x and/or y coordinates, must exit)\n", GMT_program, n_read);
@@ -511,7 +517,7 @@ main(int argc, char **argv)
 				if (this_font[0] >= '0' && this_font[0] <= '9')	/* Gave a font # */
 					T.paragraph_font = atoi (this_font);
 				else {	/* Gave a font name */
-					T.paragraph_font = GMT_key_lookup (&this_font[1], GMT_font_name, N_FONTS);
+					T.paragraph_font = GMT_key_lookup (this_font, GMT_font_name, N_FONTS);
 					if (T.paragraph_font == N_FONTS) {
 						fprintf (stderr, "%s: Record %d had bad font (set to %s (0))\n", GMT_program, n_read, GMT_font_name[0]);
 						T.paragraph_font = 0;
@@ -575,9 +581,9 @@ main(int argc, char **argv)
 
 int GMT_just_decode (char *key)
 {
-	int i, j, k;
+	int i = -1, j = -1, k;
 
-	/* Converts jusitifaction info like ll (lower left) to justification indeces */
+	/* Converts justification info like LL (lower left) to justification indices */
 
 	for (k = 0; k < (int)strlen (key); k++) {
 		switch (key[k]) {
@@ -610,6 +616,15 @@ int GMT_just_decode (char *key)
 		}
 	}
 
+	if (i < 0) {
+		fprintf (stderr, "%s: Horizontal text justification not set, defaults to L(eft)\n", GMT_program);
+		i = 1;
+	}
+	if (j < 0) {
+		fprintf (stderr, "%s: Vertical text justification not set, defaults to B(ottom)\n", GMT_program);
+		j = 1;
+	}
+		
 	return (j + i);
 }
 
