@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pswiggle.c,v 1.4 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: pswiggle.c,v 1.4.4.6 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
  *
  * Author:	Paul Wessel
  * Date:	20-JUN-2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
  
@@ -323,7 +323,7 @@ main (int argc, char **argv)
 		
 		if (!nofile && gmtdefs.verbose) {
 			fprintf (stderr, "%s: Working on file %s\n", GMT_program, argv[fno]);
-			sprintf (line, "File %s\0", argv[fno]);
+			sprintf (line, "File %s", argv[fno]);
 			ps_comment (line);
 		}
 		
@@ -495,13 +495,13 @@ void plot_wiggle (double *x, double *y, double *z, int np, double zscale, BOOLEA
 	
 	
 	if (paint_wiggle) { /* First shade wiggles */
-		sprintf (comment, "%s wiggle\0", name[negative]);
+		sprintf (comment, "%s wiggle", name[negative]);
 		ps_comment (comment);
 		GMT_fill (GMT_x_plot, GMT_y_plot, n, fill, FALSE);
 	}
 	
 	if (outline) { /* Then draw wiggle outline */
-		sprintf (comment, "Wiggle line\0");
+		sprintf (comment, "Wiggle line");
 		ps_comment (comment);
 		GMT_setpen (pen_o);
 		ps_line (&GMT_x_plot[1], &GMT_y_plot[1], np, 3, FALSE, TRUE);
@@ -509,7 +509,7 @@ void plot_wiggle (double *x, double *y, double *z, int np, double zscale, BOOLEA
 	
 	if (track) {	/* Finally draw track line */
 		if (project_info.three_D) GMT_2D_to_3D (x, y, np);
-		sprintf (comment, "Track line\0");
+		sprintf (comment, "Track line");
 		ps_comment (comment);
 		GMT_setpen (pen_t);
 		ps_line (x, y, np, 3, FALSE, TRUE);
@@ -529,9 +529,9 @@ void GMT_draw_z_scale (double x0, double y0, double length, double zscale, BOOLE
 	}
 		
 	if (units)
-		sprintf (txt, "%lg %s\0", length, units);
+		sprintf (txt, "%lg %s", length, units);
 	else
-		sprintf (txt, "%lg\0", length);
+		sprintf (txt, "%lg", length);
 	dy = 0.5 * length * zscale;	
 	GMT_xyz_to_xy (x0 + gmtdefs.map_scale_height, y0 - dy, 0.0, &a, &b);
 	ps_plot (a, b, 3);
