@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psxy.c,v 1.3 2001/04/04 00:59:32 pwessel Exp $
+ *	$Id: psxy.c,v 1.3.4.10 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
  *
  * Author:	Paul Wessel
  * Date:	29-AUG-2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
 
@@ -461,7 +461,6 @@ main (int argc, char **argv)
 	if (S.symbol == TEXT && fill_set && !outline) ps_setpaint (fill.rgb);
 	
 	if (S.symbol == TEXT) {
-		font_size = irint (S.size * 72.0);	/* To get points */
 		ps_setfont (S.font_no);			/* Set the required font */
 	}
 	if (S.symbol == FRONT || (S.symbol > 0 && skip_if_outside)) {
@@ -494,7 +493,7 @@ main (int argc, char **argv)
 
 		if (!nofile && gmtdefs.verbose) {
 			fprintf (stderr, "%s: Working on file %s\n", GMT_program, argv[fno]);
-			sprintf (line, "File: %s\0", argv[fno]);
+			sprintf (line, "File: %s", argv[fno]);
 			ps_comment (line);
 		}
 		if (gmtdefs.io_header) for (i = 0; i < gmtdefs.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
@@ -550,10 +549,10 @@ main (int argc, char **argv)
 				S.size = 0.0;
 				if (S.read_size) {
 					S.size = in[two] * GMT_u2u[S.u][GMT_INCH];
-					if (S.symbol == TEXT) font_size = irint (S.size * 72.0);
 				}
 				if (read_symbol) {
 					i = strlen (GMT_io.current_record) - 1;
+					GMT_io.current_record[i--] = 0;	/* Chop off \n */
 					while (GMT_io.current_record[i] && !strchr (" ,\t", (int)GMT_io.current_record[i])) i--;
 					(void ) decode_symbol_option (&GMT_io.current_record[i+1], &S);
 					n_required = n_cols_start + S.n_required;
@@ -563,6 +562,7 @@ main (int argc, char **argv)
 					n_required = n_cols_start + S.n_required;
 				}
 
+				if (S.symbol == BAR) GMT_geo_to_xy (west, S.base, &plot_x, &y0);	/* Zero level for bars */
 				if (get_rgb) {
 					GMT_get_rgb24 (in[2], fill.rgb);
 					if (S.symbol == CROSS || S.symbol == POINT || S.symbol == TEXT) ps_setpaint (fill.rgb);
@@ -590,7 +590,7 @@ main (int argc, char **argv)
 				
 				/* Skip zero-size symbols */
 				
-				if (S.symbol != POINT && S.symbol < ELLIPSE && S.size <= 0.0) {
+				if (!(S.symbol == POINT || S.symbol == BAR) && S.symbol < ELLIPSE && S.size <= 0.0) {
 					if (gmtdefs.verbose) fprintf (stderr, "%s: Warning: Symbol size <= 0.0 near line %d (skipped)\n", GMT_program, n_total_read);
 					continue;
 				}
@@ -673,6 +673,7 @@ main (int argc, char **argv)
 						ps_diamond (plot_x, plot_y, S.size, fill.rgb, outline);
 						break;
 					case TEXT:
+						font_size = irint (S.size * 72.0);	/* To get points */
 						if (outline && fill_set) {
 							ps_setpaint (fill.rgb);
 							ps_text (plot_x, plot_y, font_size, S.string, 0.0, 6, FALSE);
@@ -874,6 +875,7 @@ int decode_symbol_option (char *text, struct PSXY_SYMBOL *p)
 	BOOLEAN check = TRUE, old_style;
 	char symbol_type, txt_a[32], txt_b[32], txt_c[32], text_cp[128], *c;
 	p->n_required = 0;
+	p->user_unit = p->convert_angles = p->shrink = p->read_vector = FALSE;
 
 	if (!text) return -1;
 
@@ -925,9 +927,10 @@ int decode_symbol_option (char *text, struct PSXY_SYMBOL *p)
 		n = sscanf (text_cp, "%c%s", &symbol_type, txt_a);
 		if (n == 2) {
 			if (p->user_unit)
-				p->size = p->given_size = atof (txt_a);
+				p->size = atof (txt_a);
 			else
-				p->size = p->given_size = GMT_convert_units (txt_a, GMT_INCH);
+				p->size = GMT_convert_units (txt_a, GMT_INCH);
+			p->given_size = p->size;
 		}
 		else	/* No size given */
 			if (p->size == 0.0) p->size = p->given_size;
