@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psxyz.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: psxyz.c,v 1.2.4.8 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
  *
  * Author:    Paul Wessel
  * Date:      22-AUG-2000
- * Version:   3.4
+ * Version:   3.4.3
  *
  */
 
@@ -330,7 +330,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "\t     Furthermore, <size> means arrowwidth/headlength/headwith [Default is %lg/%lg/%lg]\n", S.v_width, S.h_length, S.h_width);
 		fprintf (stderr, "\t     If -SV rather than -Sv is selected, psxyz will expect azimuth and length\n");
 		fprintf (stderr, "\t     and convert azimuths based on the chosen map projection\n");		GMT_explain_option ('U');
-		fprintf (stderr, "\t   Wedges: the start and stop directions of pie wedge must be in input columns 3, 4.\n");
+		fprintf (stderr, "\t   Wedges: the start and stop directions of pie wedge must be in input columns 4 and 5.\n");
 		GMT_explain_option ('V');
 		fprintf (stderr, "\t-W sets pen attributes [width = %lgp, color = (%d/%d/%d), solid line].\n", 
 			pen.width, pen.rgb[0], pen.rgb[1], pen.rgb[2]);
@@ -472,7 +472,7 @@ main (int argc, char **argv)
 
 		if (!nofile && gmtdefs.verbose) {
 			fprintf (stderr, "%s: Working on file %s\n", GMT_program, argv[fno]);
-			sprintf (line, "File: %s\0", argv[fno]);
+			sprintf (line, "File: %s", argv[fno]);
 			ps_comment (line);
 		}
 		if (gmtdefs.io_header) for (i = 0; i < gmtdefs.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
@@ -537,6 +537,7 @@ main (int argc, char **argv)
 
 				if (read_symbol) {
 					i = strlen (GMT_io.current_record) - 1;
+					GMT_io.current_record[i--] = 0;	/* Chop off the \n */
 					while (GMT_io.current_record[i] && !strchr (" ,\t", (int)GMT_io.current_record[i])) i--;
 					decode_symbol_option (&GMT_io.current_record[i+1], &S, FALSE);
 					n_required = n_cols_start + S.n_required;
@@ -1524,12 +1525,9 @@ void GMT_plot_ellipse (double lon, double lat, double z, double major, double mi
 
 	int i, plot_n, start, n_use;
 	double delta_azimuth, sin_azimuth, cos_azimuth, sinp, cosp, angle, x, y, x_prime, y_prime, rho, c;
-	double sin_c, cos_c, keep_z; 
+	double sin_c, cos_c; 
 	double *px, *py, *xp, *yp;
 
-	keep_z = project_info.z_level;
-	project_info.z_level = z;
-
 	px = (double *) GMT_memory (VNULL, (size_t)GMT_ELLIPSE_APPROX, sizeof (double), GMT_program);
 	py = (double *) GMT_memory (VNULL, (size_t)GMT_ELLIPSE_APPROX, sizeof (double), GMT_program);
 
@@ -1585,23 +1583,22 @@ void GMT_plot_ellipse (double lon, double lat, double z, double major, double mi
 						
 		GMT_n_plot = (*GMT_truncate) (xp, yp, plot_n, start, -1);
 		n_use = GMT_compact_line (GMT_x_plot, GMT_y_plot, GMT_n_plot, FALSE, 0);
-		GMT_2D_to_3D (GMT_x_plot, GMT_y_plot, GMT_n_plot);
+		GMT_2Dz_to_3D (GMT_x_plot, GMT_y_plot, z, GMT_n_plot);
 		GMT_fill (GMT_x_plot, GMT_y_plot, n_use, &fill, outline);
 								
 		/* Then truncate agains right border */
 						
 		GMT_n_plot = (*GMT_truncate) (xp, yp, plot_n, start, +1);
 		n_use = GMT_compact_line (GMT_x_plot, GMT_y_plot, GMT_n_plot, FALSE, 0);
-		GMT_2D_to_3D (GMT_x_plot, GMT_y_plot, GMT_n_plot);
+		GMT_2Dz_to_3D (GMT_x_plot, GMT_y_plot, z, GMT_n_plot);
 		GMT_fill (GMT_x_plot, GMT_y_plot, n_use, &fill, outline);
 						
 	}
 	else {
-		GMT_2D_to_3D (xp, yp, plot_n);
+		GMT_2Dz_to_3D (xp, yp, z, plot_n);
 		GMT_fill (xp, yp, plot_n, &fill, outline);
 	}
 
-	project_info.z_level = keep_z;
 	GMT_free ((void *)xp);
 	GMT_free ((void *)yp);
 	GMT_free ((void *)px);
