@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: sample1d.c,v 1.3 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: sample1d.c,v 1.3.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
  *
  * Author:	Paul Wessel
  * Date:	05-JUL--2000
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
  
@@ -135,7 +135,7 @@ main (int argc, char **argv)
 	if (argc == 1 || GMT_quick) {	/* Display usage */
 		fprintf (stderr,"sample1d %s - Resampling of 1-D data sets\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: sample1d <infile(s)> [-Fl|a|c] [-H[<nrec>]] [-I<t_inc>] [-M[<flag>]] [-N<knotfile>]\n");
-		fprintf (stderr, "\t[-S<xstart>] [-T<time_col>] [-V] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf (stderr, "\t[-S<xstart>] [-T<time_col>] [-V] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -172,10 +172,6 @@ main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR: Specify only one of -N and -S\n", GMT_program);
 		error++;
 	}
-	if (!t_supplied && !equidist) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR: Must specify one of -N and -S\n", GMT_program);
-		error++;
-	}
 	if (got_dt && dt <= 0.0) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -I option: Must specify positive increment\n", GMT_program);
 		error++;
