@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: spectrum1d.c,v 1.3 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: spectrum1d.c,v 1.3.4.8 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -65,7 +65,7 @@
  *			modified periodograms", IEEE Transactions on
  *			Audio and Electroacoustics, Vol AU-15, No 2,
  *			June, 1967.
- *  Version:	3.4
+ *  Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -109,7 +109,7 @@ main (int argc, char **argv)
 
 	n_outputs = 0;	
 	for (i=0; i < N_OUTPUT_CHOICES; i++) output_choice[i] = 0;
-	sprintf(namestem, "spectrum\0");
+	sprintf (namestem, "spectrum");
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -209,7 +209,7 @@ main (int argc, char **argv)
 
 	if (argc == 1 || GMT_quick) {	/* Display usage */
 		fprintf (stderr, "spectrum1d %s - compute auto- [and cross- ] spectra from one [or two] timeseries\n\n", GMT_VERSION);
-		fprintf(stderr,"usage:  spectrum1d -S<segment_size> [-C[<xycnpago>]] [-D<dt>] [-H[<nrec>]] [-N<name_stem>] [-V] [-W] [-bi[s][<n>]] [-bo[s]]\n");
+		fprintf(stderr,"usage:  spectrum1d -S<segment_size> [-C[<xycnpago>]] [-D<dt>] [-H[<nrec>]] [-N<name_stem>] [-V] [-W] [-bi[s][<n>]] [-bo[s][<n>]]\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -252,7 +252,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 		error++;
 	}
-        if (GMT_io.binary[0] && GMT_io.ncol[0] == 0) GMT_io.ncol[0] = 2;
+        if (GMT_io.binary[0] && GMT_io.ncol[0] == 0) GMT_io.ncol[0] = (y_given + 1);
         if (GMT_io.binary[0] && GMT_io.ncol[0] < (y_given + 1)) {
                 fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data must have at least %d columns\n", GMT_program, y_given + 1);
 		error++;
@@ -314,7 +314,7 @@ void	read_data(void)
 	n_data = 0;
 	x = (float *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(float), GMT_program);
 	if (y_given) y = (float *)GMT_memory (VNULL, (size_t)n_alloc, sizeof(float), GMT_program);
-	n_expected_fields = (GMT_io.ncol[0]) ? GMT_io.ncol[0] : 2;
+	n_expected_fields = (GMT_io.ncol[0]) ? GMT_io.ncol[0] : y_given + 1;
 
 	if (gmtdefs.io_header) for (i = 0; i < gmtdefs.n_header_recs; i++) GMT_fgets (buffer, BUFSIZ, fp);
 
@@ -426,7 +426,7 @@ void	compute_spectra(void)
 		if (gmtdefs.verbose) {
 			y_pow = (y_given) ? y_variance/y_varp : 0.0;
 			fprintf(stderr,"Window %d from %d to %d\n", w, t_start, t_stop);
-			sprintf(format, "X var:  %s  X pow:  %s  ratio:  %s  Y var:  %s  Y pow:  %s  ratio:  %s\n\0",
+			sprintf(format, "X var:  %s  X pow:  %s  ratio:  %s  Y var:  %s  Y pow:  %s  ratio:  %s\n",
 				gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 			fprintf(stderr, format, x_variance, x_varp, (x_variance/x_varp), y_variance, y_varp, y_pow);
 		}
@@ -471,7 +471,7 @@ void	write_output(char *output_choice, int n_outputs)
 	for (j = 0; j < n_outputs; j++) {
 	  switch (output_choice[j]) {
 	  case 'x':		/* write x power */
-	    sprintf(fname, "%s.xpower\0", namestem);
+	    sprintf(fname, "%s.xpower", namestem);
 	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
 	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
 	      exit (EXIT_FAILURE);
@@ -487,7 +487,7 @@ void	write_output(char *output_choice, int n_outputs)
 	    break;
 
 	  case 'y':		/* Write y power  */
-	    sprintf(fname, "%s.ypower\0", namestem);
+	    sprintf(fname, "%s.ypower", namestem);
 	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
 	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
 	      exit (EXIT_FAILURE);
@@ -502,7 +502,7 @@ void	write_output(char *output_choice, int n_outputs)
 	    GMT_fclose(fpout);
 	    break;
 	  case 'c':		/* Write Coherent Output power  */
-	    sprintf(fname, "%s.cpower\0", namestem);
+	    sprintf(fname, "%s.cpower", namestem);
 	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
 	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
 	      exit (EXIT_FAILURE);
@@ -517,7 +517,7 @@ void	write_output(char *output_choice, int n_outputs)
 	    GMT_fclose(fpout);
 	    break;
 	  case 'n':		/* Write Noise Output power  */
-	    sprintf(fname, "%s.npower\0", namestem);
+	    sprintf(fname, "%s.npower", namestem);
 	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
 	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
 	      exit (EXIT_FAILURE);
@@ -532,7 +532,7 @@ void	write_output(char *output_choice, int n_outputs)
 	    GMT_fclose(fpout);
 	    break;
 	  case 'g':		/* Write Gain spectrum  */
-	    sprintf(fname, "%s.gain\0", namestem);
+	    sprintf(fname, "%s.gain", namestem);
 	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
 	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
 	      exit (EXIT_FAILURE);
@@ -547,7 +547,7 @@ void	write_output(char *output_choice, int n_outputs)
 	    GMT_fclose(fpout);
 	    break;
 	  case 'a':		/* Write Real Admittance spectrum  */
-	    sprintf(fname, "%s.admit\0", namestem);
+	    sprintf(fname, "%s.admit", namestem);
 	    if ( (fpout = GMT_fopen(fname, "w")) == NULL) {
 	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
 	      exit (EXIT_FAILURE);
@@ -562,7 +562,7 @@ void	write_output(char *output_choice, int n_outputs)
 	    GMT_fclose(fpout);
 	    break;
 	  case 'p':		/* Write Phase spectrum  */
-	    sprintf(fname, "%s.phase\0", namestem);
+	    sprintf(fname, "%s.phase", namestem);
 	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
 	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
 	      exit (EXIT_FAILURE);
@@ -576,7 +576,7 @@ void	write_output(char *output_choice, int n_outputs)
 	    }
 	    GMT_fclose(fpout);
 	  case 'o':		/* Write Coherency spectrum  */
-	    sprintf(fname, "%s.coh\0", namestem);
+	    sprintf(fname, "%s.coh", namestem);
 	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
 	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
 	      exit (EXIT_FAILURE);
