@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: splitxyz.c,v 1.2 2001/03/01 22:08:26 pwessel Exp $
+ *	$Id: splitxyz.c,v 1.2.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,8 +21,8 @@
  * and split it into profile segments.
  * 
  * Author:	W. H. F. Smith
- * Date:	24 July, 1991-2000
- * Version:	3.4
+ * Date:	24 July, 1991-2001
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -140,7 +140,7 @@ main(int argc, char **argv)
  		fprintf (stderr, "splitxyz %s - Split xyz[dh] files into segments\n\n", GMT_VERSION);
 		fprintf(stderr,"usage:  splitxyz [<xyz[dh]file>] -C<course_change> [-A<azimuth>/<tolerance>]\n");
 		fprintf(stderr,"\t[-D<minimum_distance>] [-F<xy_filter>/<z_filter>] [-G<gap>] [-H[<nrec>]] [-M]\n");
-		fprintf(stderr,"\t[-N<namestem>] [-S] [-V] [-Z] [-:] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf(stderr,"\t[-N<namestem>] [-S] [-V] [-Z] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
  		
 		if (GMT_quick) exit (EXIT_FAILURE);
 		
@@ -385,7 +385,7 @@ main(int argc, char **argv)
 					/* If (basename) we write separate files, else GMT_stdout with > marks:  */
 					
 					if (basename[0]) {
-						sprintf(filename, "%s.profile%d\0", basename, nprofiles);
+						sprintf(filename, "%s.profile%d", basename, nprofiles);
 						if ( (fpout = GMT_fopen(filename, GMT_io.w_mode)) == NULL) {
 							fprintf(stderr,"%s:  Cannot create %s\n", GMT_program, argv[i]);
 							exit (EXIT_FAILURE);
