@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: surface.c,v 1.4 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: surface.c,v 1.4.4.9 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -76,7 +76,7 @@
  *
  * 24-JAN-2000 PW/WHFS: Fixed bug related to use of -L option for "near-node" constraints.
  * 10-JUL-2000 3.3.5 PW: Added -L plain.
- * Version:	3.4
+ * Version:	3.4.3
  *
  *
  */
@@ -106,7 +106,7 @@ int set_low = 0;		/* 0 unconstrained,1 = by min data value, 2 = by user value */
 int set_high = 0;		/* 0 unconstrained,1 = by max data value, 2 = by user value */
 int constrained = FALSE;	/* TRUE if set_low or set_high is TRUE */
 double low_limit, high_limit;	/* Constrains on range of solution */
-double xmin, xmax, ymin, ymax;	/* minmax coordinates */
+double x_min, x_max, y_min, y_max;	/* minmax coordinates */
 float *lower, *upper;		/* arrays for minmax values, if set */
 double xinc, yinc;		/* Size of each grid cell (final size) */
 double grid_xinc, grid_yinc;	/* size of each grid cell for a given grid factor */
@@ -120,7 +120,7 @@ double	a0_const_1, a0_const_2;	/* Constants for off grid point equation  */
 double	e_2, e_m2, one_plus_e2;
 double eps_p2, eps_m2, two_plus_ep2, two_plus_em2;
 double	x_edge_const, y_edge_const;
-double	epsilon = 1.0;
+double	l_epsilon = 1.0;
 double	z_mean;
 double	z_scale = 1.0;		/* Root mean square range of z after removing planar trend  */
 double	r_z_scale = 1.0;	/* reciprocal of z_scale  */
@@ -183,8 +183,8 @@ main(int argc, char **argv)
 
 	GMT_grd_init (&h, argc, argv, FALSE);
 
-	xmin = ymin = 0.0;
-	xmax = ymax = 0.0;
+	x_min = y_min = 0.0;
+	x_max = y_max = 0.0;
 	xinc = yinc = 0.0;
 
 	/* New in v4.3:  Default to unconstrained:  */
@@ -202,7 +202,7 @@ main(int argc, char **argv)
 				case 'R':
 				case ':':
 				case '\0':
-                                      error += GMT_get_common_args (argv[i], &xmin, &xmax, &ymin, &ymax);
+                                      error += GMT_get_common_args (argv[i], &x_min, &x_max, &y_min, &y_max);
                                       break;
                               
 				/* Supplemental parameters */
@@ -211,7 +211,7 @@ main(int argc, char **argv)
 					error += GMT_io_selection (&argv[i][2]);
 					break;
 				case 'A':
-					epsilon = atof (&argv[i][2]);
+					l_epsilon = atof (&argv[i][2]);
 					break;
 				case 'C':
 					converge_limit = atof (&argv[i][2]);
@@ -411,10 +411,10 @@ main(int argc, char **argv)
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[0], type[GMT_io.single_precision[0]]);
 	}
 
-	h.x_min = xmin;
-	h.x_max = xmax;
-	h.y_min = ymin;
-	h.y_max = ymax;
+	h.x_min = x_min;
+	h.x_max = x_max;
+	h.y_min = y_min;
+	h.y_max = y_max;
 	h.x_inc = xinc;
 	h.y_inc = yinc;
 
@@ -426,8 +426,8 @@ main(int argc, char **argv)
 	}
 	relax_old = 1.0 - relax_new;
 
-	nx = irint ((xmax - xmin)/xinc) + 1;
-	ny = irint ((ymax - ymin)/yinc) + 1;
+	nx = irint ((x_max - x_min)/xinc) + 1;
+	ny = irint ((y_max - y_min)/yinc) + 1;
 	h.nx = nx;
 	h.ny = ny;
 	mx = nx + 4;
@@ -439,8 +439,8 @@ main(int argc, char **argv)
 	grid = gcd_euclid (nx-1, ny-1);
 
 	if (gmtdefs.verbose || size_query) {
-		sprintf (format, "W: %s E: %s S: %s N: %s nx: %%d ny: %%d\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
-		fprintf (stderr, format, xmin, xmax, ymin, ymax, nx-1, ny-1);
+		sprintf (format, "W: %s E: %s S: %s N: %s nx: %%d ny: %%d\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		fprintf (stderr, format, x_min, x_max, y_min, y_max, nx-1, ny-1);
 	}
 	if (grid == 1 && gmtdefs.verbose) fprintf(stderr,"%s:  WARNING:  Your grid dimensions are mutually prime.\n", GMT_program);
 	if (( grid == 1 && gmtdefs.verbose) || size_query) suggest_sizes_for_surface(nx-1, ny-1);
@@ -528,7 +528,7 @@ void	set_coefficients(void)
 	double	e_4, loose, a0;
 	
 	loose = 1.0 - interior_tension;
-	e_2 = epsilon * epsilon;
+	e_2 = l_epsilon * l_epsilon;
 	e_4 = e_2 * e_2;
 	eps_p2 = e_2;
 	eps_m2 = 1.0/e_2;
@@ -702,8 +702,8 @@ struct DATA *point_1, *point_2;
 	else {	/* Points are in same grid cell, find the one who is nearest to grid point */
 		block_i = point_1->index/block_ny;
 		block_j = point_1->index%block_ny;
-		x0 = xmin + block_i * grid_xinc;
-		y0 = ymin + block_j * grid_yinc;
+		x0 = x_min + block_i * grid_xinc;
+		y0 = y_min + block_j * grid_yinc;
 		dist_1 = (point_1->x - x0) * (point_1->x - x0) + (point_1->y - y0) * (point_1->y - y0);
 		dist_2 = (point_2->x - x0) * (point_2->x - x0) + (point_2->y - y0) * (point_2->y - y0);
 		if (dist_1 < dist_2)
@@ -728,8 +728,8 @@ void set_index (void) {
 	int i, j, k, k_skipped = 0;
 
 	for (k = 0; k < npoints; k++) {
-		i = (int)floor(((data[k].x-xmin)*r_grid_xinc) + 0.5);
-		j = (int)floor(((data[k].y-ymin)*r_grid_yinc) + 0.5);
+		i = (int)floor(((data[k].x-x_min)*r_grid_xinc) + 0.5);
+		j = (int)floor(((data[k].y-y_min)*r_grid_yinc) + 0.5);
 		if (i < 0 || i >= block_nx || j < 0 || j >= block_ny) {
 			data[k].index = OUTSIDE;
 			k_skipped++;
@@ -764,8 +764,8 @@ void find_nearest_point(void) {
 			block_j = data[k].index%block_ny;
 			last_index = data[k].index;
 	 		iu_index = ij_sw_corner + (block_i * my + block_j) * grid;
-	 		x0 = xmin + block_i*grid_xinc;
-	 		y0 = ymin + block_j*grid_yinc;
+	 		x0 = x_min + block_i*grid_xinc;
+	 		y0 = y_min + block_j*grid_yinc;
 	 		dx = (data[k].x - x0)*r_grid_xinc;
 	 		dy = (data[k].y - y0)*r_grid_yinc;
 	 		if (fabs(dx) < small && fabs(dy) < small) {	/* Close enough to assign value to node */
@@ -848,9 +848,9 @@ void initialize_grid(void)
 	 rfact = -4.5/(radius*radius);
 	 
 	 for (i = 0; i < block_nx; i ++ ) {
-	 	x0 = xmin + i*grid_xinc;
+	 	x0 = x_min + i*grid_xinc;
 	 	for (j = 0; j < block_ny; j ++ ) {
-	 		y0 = ymin + j*grid_yinc;
+	 		y0 = y_min + j*grid_yinc;
 	 		imin = i - irad;
 	 		if (imin < 0) imin = 0;
 	 		imax = i + irad;
@@ -878,7 +878,7 @@ void initialize_grid(void)
 	 			}
 	 		}
 	 		if (sum_w == 0.0) {
-	 			sprintf (format, "%%s: Warning: no data inside search radius at: %s %s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+	 			sprintf (format, "%%s: Warning: no data inside search radius at: %s %s\n", gmtdefs.d_format, gmtdefs.d_format);
 	 			fprintf (stderr, format, GMT_program, x0, y0);
 	 			u[ij_sw_corner + (i * my + j) * grid] = (float)z_mean;
 	 		}
@@ -905,8 +905,8 @@ void new_initialize_grid(void)
 	while (k < npoints) {
 		block_i = data[k].index / block_ny;
 		block_j = data[k].index % block_ny;
-		x0 = xmin + block_i*grid_xinc;
-		y0 = ymin + block_j*grid_yinc;
+		x0 = x_min + block_i*grid_xinc;
+		y0 = y_min + block_j*grid_yinc;
 		u_index = ij_sw_corner + (block_i*my + block_j) * grid;
 		k_index = data[k].index;
 		
@@ -956,9 +956,9 @@ void read_data(void)
 
 		if (GMT_is_dnan (in[2])) continue;
 		
-		i = (int)floor(((in[0]-xmin)*r_grid_xinc) + 0.5);
+		i = (int)floor(((in[0]-x_min)*r_grid_xinc) + 0.5);
 		if (i < 0 || i >= block_nx) continue;
-		j = (int)floor(((in[1]-ymin)*r_grid_yinc) + 0.5);
+		j = (int)floor(((in[1]-y_min)*r_grid_yinc) + 0.5);
 		if (j < 0 || j >= block_ny) continue;
 
 		data[k].index = i * block_ny + j;
@@ -986,7 +986,7 @@ void read_data(void)
 	
 	z_mean /= k;
 	if (gmtdefs.verbose) {
-		sprintf(format, "%s %s %s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+		sprintf(format, "%s %s %s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf(stderr, "%s: Minimum value of your dataset x,y,z at: ", GMT_program);
 		fprintf(stderr, format, (double)data[kmin].x, (double)data[kmin].y, (double)data[kmin].z);
 		fprintf(stderr, "%s: Maximum value of your dataset x,y,z at: ", GMT_program);
@@ -1038,11 +1038,11 @@ int	iterate(int mode)
 	
 	double	x_0_const = 4.0 * (1.0 - boundary_tension) / (2.0 - boundary_tension);
 	double	x_1_const = (3 * boundary_tension - 2.0) / (2.0 - boundary_tension);
-	double	y_denom = 2 * epsilon * (1.0 - boundary_tension) + boundary_tension;
-	double	y_0_const = 4 * epsilon * (1.0 - boundary_tension) / y_denom;
-	double	y_1_const = (boundary_tension - 2 * epsilon * (1.0 - boundary_tension) ) / y_denom;
+	double	y_denom = 2 * l_epsilon * (1.0 - boundary_tension) + boundary_tension;
+	double	y_0_const = 4 * l_epsilon * (1.0 - boundary_tension) / y_denom;
+	double	y_1_const = (boundary_tension - 2 * l_epsilon * (1.0 - boundary_tension) ) / y_denom;
 
-	sprintf(format,"%%4d\t%%c\t%%8d\t%s\t%s\t%%10d\n\0", gmtdefs.d_format, gmtdefs.d_format);
+	sprintf(format,"%%4d\t%%c\t%%8d\t%s\t%s\t%%10d\n", gmtdefs.d_format, gmtdefs.d_format);
 
 	do {
 		briggs_index = 0;	/* Reset the constraint table stack pointer  */
@@ -1276,9 +1276,9 @@ void check_errors (void) {
 	
 	double	x_0_const = 4.0 * (1.0 - boundary_tension) / (2.0 - boundary_tension);
 	double	x_1_const = (3 * boundary_tension - 2.0) / (2.0 - boundary_tension);
-	double	y_denom = 2 * epsilon * (1.0 - boundary_tension) + boundary_tension;
-	double	y_0_const = 4 * epsilon * (1.0 - boundary_tension) / y_denom;
-	double	y_1_const = (boundary_tension - 2 * epsilon * (1.0 - boundary_tension) ) / y_denom;
+	double	y_denom = 2 * l_epsilon * (1.0 - boundary_tension) + boundary_tension;
+	double	y_0_const = 4 * l_epsilon * (1.0 - boundary_tension) / y_denom;
+	double	y_1_const = (boundary_tension - 2 * l_epsilon * (1.0 - boundary_tension) ) / y_denom;
 	
 	
 	move_over[0] = 2;
@@ -1360,8 +1360,8 @@ void check_errors (void) {
 		j = data[k].index%ny;
 	 	ij = ij_sw_corner + i * my + j;
 	 	if ( iu[ij] == 5 ) continue;
-	 	x0 = xmin + i*xinc;
-	 	y0 = ymin + j*yinc;
+	 	x0 = x_min + i*xinc;
+	 	y0 = y_min + j*yinc;
 	 	dx = (data[k].x - x0)*r_xinc;
 	 	dy = (data[k].y - y0)*r_yinc;
  
@@ -1406,7 +1406,7 @@ void check_errors (void) {
 	}
 
 	 fprintf(stderr, "Fit info: N data points  N nodes\tmean error\trms error\tcurvature\n");
-	 sprintf (format,"\t%%8d\t%%8d\t%s\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+	 sprintf (format,"\t%%8d\t%%8d\t%s\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 	 fprintf (stderr, format, npoints, n_nodes, mean_error, mean_squared_error, curvature);
  }
 
@@ -1421,8 +1421,8 @@ void	remove_planar_trend(void)
 	
 	for (i = 0; i < npoints; i++) {
 
-		xx = (data[i].x - xmin) * r_xinc;
-		yy = (data[i].y - ymin) * r_yinc;
+		xx = (data[i].x - x_min) * r_xinc;
+		yy = (data[i].y - y_min) * r_yinc;
 		zz = data[i].z;
 		
 		sx += xx;
@@ -1452,8 +1452,8 @@ void	remove_planar_trend(void)
 
 	for (i = 0; i < npoints; i++) {
 
-		xx = (data[i].x - xmin) * r_xinc;
-		yy = (data[i].y - ymin) * r_yinc;
+		xx = (data[i].x - x_min) * r_xinc;
+		yy = (data[i].y - y_min) * r_yinc;
 		
 		data[i].z -= (float)(plane_c0 + plane_c1 * xx + plane_c2 * yy);
 	}
@@ -1527,11 +1527,11 @@ void	rescale_z_values(void)
 	z_scale = sqrt (ssz / npoints);
 	
 	if (z_scale == 0.0) {
-		fprintf(stderr,"%s: Input data lie exactly on a plane - no solution (aborting).\n", GMT_program);
-		exit (EXIT_FAILURE);
+		fprintf (stderr, "%s: WARNING: Input data lie exactly on a plane.\n", GMT_program);
+		r_z_scale = z_scale = 1.0;
 	}
-	
-	r_z_scale = 1.0 / z_scale;
+	else
+		r_z_scale = 1.0 / z_scale;
 
 	for (i = 0; i < npoints; i++) data[i].z *= (float)r_z_scale;
 
@@ -1623,7 +1623,7 @@ double	guess_surface_time(int nx, int ny)
 {
 	/* Routine to guess a number proportional to the operations
 	 * required by surface working on a user-desired grid of
-	 * size nx by ny, where nx = (xmax - xmin)/dx, and same for
+	 * size nx by ny, where nx = (x_max - x_min)/dx, and same for
 	 * ny.  (That is, one less than actually used in routine.)
 	 *
 	 * This is based on the following untested conjecture:
@@ -1698,7 +1698,7 @@ void	suggest_sizes_for_surface(int nx, int ny)
 	 * within the range (nx,ny) - (2*nx, 2*ny).  Prints to
 	 * stderr the values which are an improvement over the
 	 * user's original nx,ny.
-	 * Should be called with nx=(xmax-xmin)/dx, and ditto
+	 * Should be called with nx=(x_max-x_min)/dx, and ditto
 	 * for ny; that is, one smaller than the lattice used
 	 * in surface.c
 	 *
