@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: trend1d.c,v 1.3 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: trend1d.c,v 1.3.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -100,7 +100,7 @@
  * Revised:	11 June, 1991-2000 for v2.0 of GMT-SYSTEM.
  *		13-JUN-1998, for GMT 3.1 (PW)
  *		13-JUL-2000, for GMT 3.3.5 (PW)
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -244,7 +244,7 @@ main(int argc, char **argv)
 	if (argc == 1 || GMT_quick) {
 		fprintf(stderr,"trend1d %s - Fit a [weighted] [robust] polynomial [or Fourier] model for y = f(x) to ascii xy[w]\n\n", GMT_VERSION);
 		fprintf(stderr,"usage:  trend1d -F<xymrw> -N[f]<n_model>[r] [<xy[w]file>] [-C<condition_#>]\n");
-		fprintf(stderr,"\t[-H[<nrec>]] [-I[<confidence>]] [-V] [-W] [-:] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf(stderr,"\t[-H[<nrec>]] [-I[<confidence>]] [-V] [-W] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 
@@ -327,12 +327,12 @@ main(int argc, char **argv)
 	transform_x(data, n_data, model_type, xmin, xmax);	/* Set domain to [-1, 1] or [-pi, pi]  */
 
 	if (gmtdefs.verbose) {
-		sprintf(format,"%%s:  Read %%d data with X values from %s to %s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+		sprintf(format,"%%s:  Read %%d data with X values from %s to %s\n", gmtdefs.d_format, gmtdefs.d_format);
 		fprintf(stderr, format, GMT_program, n_data, xmin, xmax);
 		fprintf(stderr,"N_model\tRank\tChi_Squared\tSignificance\n");
 	}
 
-	sprintf (format, "%%d\t%%d\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format, "%%d\t%%d\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format);
 
 	if (increment) {
 		n_model = 1;
@@ -432,10 +432,10 @@ main(int argc, char **argv)
 	}
 
 	if (gmtdefs.verbose) {
-		sprintf (format, "%%s: Final model stats:  N model parameters %%d.  Rank %%d.  Chi-Squared:  %s\n\0", gmtdefs.d_format);
+		sprintf (format, "%%s: Final model stats:  N model parameters %%d.  Rank %%d.  Chi-Squared:  %s\n", gmtdefs.d_format);
 		fprintf(stderr, format, GMT_program, n_model, rank, c_chisq);
 		fprintf(stderr,"Model Coefficients:");
-		sprintf (format, "%s\t\0", gmtdefs.d_format);
+		sprintf (format, "%s\t", gmtdefs.d_format);
 		for (i = 0; i < n_model; i++) fprintf (stderr, format, c_model[i]);
 		fprintf(stderr,"\n");
 	}
