@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: trend2d.c,v 1.3 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: trend2d.c,v 1.3.4.8 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -62,7 +62,7 @@
  * Date:	17 June 1991-2000.
  * Revised:	12-JUN-1998 for GMT 3.1 (PW)
  *		10-JUL-2000 for GMT 3.3.5 (PW) Added -L option
- * Version:	3.4
+ * Version:	3.4.3
  */
 
 #include "gmt.h"
@@ -111,7 +111,7 @@ main(int argc, char **argv)
 	n_outputs = 0;
 	n_model_max = 0;
 	for (i = 0; i < N_OUTPUT_CHOICES; i++) output_choice[i] = 0;
-	sprintf (format, "%s\t\0", gmtdefs.d_format);
+	sprintf (format, "%s\t", gmtdefs.d_format);
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -197,14 +197,14 @@ main(int argc, char **argv)
 	if (argc == 1 || GMT_quick) {
 		fprintf(stderr,"trend2d %s - Fit a [weighted] [robust] polynomial for z = f(x,y) to ascii xyz[w]\n\n", GMT_VERSION);
 		fprintf(stderr,"usage:  trend2d -F<xymrw> -N<n_model>[r] [<xyz[w]file>] [-C<condition_#>] [-H[<nrec>]] [-I[<confidence>]]\n\n");
-		fprintf(stderr,"	[-L] [-V] [-W] [-:] [-bi[s][<n>]] [-bo[s]]\n\n");
+		fprintf(stderr,"	[-L] [-V] [-W] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
 		
 		if (GMT_quick) exit (EXIT_FAILURE);
 
 		fprintf(stderr,"\t-F Choose at least 1, up to 6, any order, of xyzmrw for ascii output to stdout.\n");
 		fprintf(stderr,"\t-N fit a [robust] model with <n_model> terms.  <n_model> in [1,10].  E.g., robust quadratic = -N3r.\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
-		fprintf(stderr,"\t[<xyz[w]file>] name of ascii file, first 2 cols = x y [3 cols = x y w].  [Default reads stdin].\n");
+		fprintf(stderr,"\t[<xyz[w]file>] name of ascii file, first 3 cols = x y z [4 cols = x y z w].  [Default reads stdin].\n");
 		fprintf(stderr,"\t   x=x, y=y, z=z, m=model, r=residual=z-m, w=weight.  w determined iteratively if robust fit used.\n");
 		fprintf(stderr,"\t-C Truncate eigenvalue spectrum so matrix has <condition_#>.  [Default = 1.0e06].\n");
 		GMT_explain_option ('H');
@@ -291,7 +291,7 @@ main(int argc, char **argv)
 		fprintf(stderr,"N_model\tRank\tChi_Squared\tSignificance\n");
 	}
 
-	sprintf (format, "%%d\t%%d\t%s\t%s\n\0", gmtdefs.d_format, gmtdefs.d_format);
+	sprintf (format, "%%d\t%%d\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format);
 
 	if (increment) {
 		n_model = 1;
@@ -391,10 +391,10 @@ main(int argc, char **argv)
 	}
 
 	if (gmtdefs.verbose) {
-		sprintf (format, "%%s: Final model stats:  N model parameters %%d.  Rank %%d.  Chi-Squared:  %s\n\0", gmtdefs.d_format);
+		sprintf (format, "%%s: Final model stats:  N model parameters %%d.  Rank %%d.  Chi-Squared:  %s\n", gmtdefs.d_format);
 		fprintf(stderr, format, GMT_program, n_model, rank, c_chisq);
 		fprintf(stderr,"Model Coefficients:");
-		sprintf (format, "%s\t\0", gmtdefs.d_format);
+		sprintf (format, "%s\t", gmtdefs.d_format);
 		for (i = 0; i < n_model; i++) {
 			fprintf(stderr, format, c_model[i]);
 		}
