@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: triangulate.c,v 1.3 2001/04/11 23:07:29 pwessel Exp $
+ *	$Id: triangulate.c,v 1.3.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
  * Revised:	02-MAR-1999 for GMT 3.2
  * Revised:	29-MAR-2000 for GMT 3.3.5
  * Modified:	10 Jul 2000 by PW to add -L
- * Version:	3.4
+ * Version:	3.4.3
  *
  */
  
@@ -89,6 +89,7 @@ main (int argc, char **argv)
         
 				case 'b':
 					error += GMT_io_selection (&argv[i][2]);
+					break;
 				case 'D':
 					do_ddx = (argv[i][2] == 'x' || argv[i][2] == 'X');
 					do_ddy = (argv[i][2] == 'y' || argv[i][2] == 'Y');
@@ -126,7 +127,7 @@ main (int argc, char **argv)
 	if (argc == 1 || GMT_quick) {
 		fprintf (stderr, "triangulate %s - Optimal (Delaunay) triangulation of xyz-data\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: triangulate <infiles> [-Dx|y] [-E<empty>] [-F] [-G<grdfile> [-H[<nrec>]] [-I<dx>[m|c][/<dy>[m|c]]] [-J<parameters>]\n");
-		fprintf (stderr, "\t[-L] [-M[<flag>]] [-R<west/east/south/north>] [-V] [-:] [-bi[s][<n>]] [-bo]\n\n");
+		fprintf (stderr, "\t[-L] [-M[<flag>]] [-R<west/east/south/north>] [-V] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
                 
 		if (GMT_quick) exit (EXIT_FAILURE);
                 
