@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: xyz2grd.c,v 1.4 2001/03/19 18:15:09 pwessel Exp $
+ *	$Id: xyz2grd.c,v 1.4.4.7 2004/01/02 22:23:11 pwessel Exp $
  *
- *	Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -32,6 +32,7 @@
  *		3.3.5	-L option finally fixed, part II.  Also added -A[z|n]
  * Version:	3.3.6
  *		3.4	Now can handle multiple input files (except with -S)
+ * Version:	3.4.3
  */
  
 #include "gmt.h"
@@ -383,7 +384,7 @@ main (int argc, char **argv)
 				ii = (int)floor ((in[0] - w) * idx + off);
 				if (ii == grd.nx) ii--, n_confused++;
 				jj = (int)floor ((n - in[1]) * idy + off);
-				if (jj == grd.ny) jj--, n_confused++;
+				if (jj == -1) jj++, n_confused++;
 				ij = jj * grd.nx + ii;
 				a[ij] += (float)in[z];	/* Add up incase we must average */
 				flag[ij]++;
@@ -430,7 +431,7 @@ main (int argc, char **argv)
 		}
 
 		if (gmtdefs.verbose) {
-			sprintf (line, "%s\n\0", gmtdefs.d_format);
+			sprintf (line, "%s\n", gmtdefs.d_format);
 			fprintf (stderr, "%s:  n_read: %d  n_used: %d  n_filled: %d  n_empty: %d set to ", GMT_program,
 				n_read, n_used, n_filled, n_empty);
 			(GMT_is_dnan (no_data_d)) ? fprintf (stderr, "NaN\n") : fprintf (stderr, line, no_data_d);
